@@ -9,6 +9,10 @@
 	;(use-modules (actions denemo-modules (string->symbol string)))) ; maybe not (string->symbol) but (eval)
 	(load (string-append "denemo-modules/" string ".scm")))
 
+
+;(bindtextdomain "denemo" "/usr/local/share/locale") find prefix!!!
+(define (_ msg) (gettext msg "denemo"))
+
 ;Load additional Denemo functions. These are technically in the same global namespace as functions defined directly in denemo.scm. 
 (use-denemo "scheme") ; Standalone functions and general Scheme helpers, not tied to any Denemo C-functions or Scheme functions which are not in the file itself.
 (use-denemo "ans") ; Abstract Note System for pitch calculations
@@ -388,10 +392,9 @@
 ;;;;;;;;;; SetHeaderField sets a field in the movement header
 ;;;;;;;;;; the directive created is tagged Score or Movement depending on the field
 
-(define* (SetHeaderField field #:optional (title #f))
+(define* (SetHeaderField field #:optional (title #f) (escape #t))
   (let ((current "") (thematch #f) (tag "") (type "") (fieldname ""))
-    (if 
-     (or (equal? field "subtitle") (equal? field "subsubtitle") (equal? field "piece"))
+    (if (or (equal? field "subtitle") (equal? field "subsubtitle") (equal? field "piece"))
      (begin
        (set! type "Movement")
        (if (equal? field "subtitle")
@@ -399,7 +402,7 @@
         (if (equal? field "subsubtitle")
 	   (set! fieldname "Subtitle"))
 	(if (equal? field "piece")
-	   (set! fieldname "Piece")) )
+	   (set! fieldname "Piece")))
      (begin
        (set! type "Score")
        (set! fieldname (string-capitalize field))))
@@ -415,23 +418,23 @@
 	  (if (regexp-match? thematch)
 	      (set! current (match:substring thematch 1)))))
     (if (not title)
-      (begin
 	(set! title (d-GetUserInput (string-append type " " fieldname)
-				    (string-append "Give a name for the " fieldname " of the " type) current))
-	(if title
-	  (begin
-	    (if (string-null? title)
+				    (string-append "Give a name for the " fieldname " of the " type) current #f)))
+    (if title
+      (begin
+	  (d-SetSaved #f)
+	  (if (string-null? title)
 	      (d-DirectiveDelete-header tag)
 	      (begin
-		(set! title (scheme-escape title ))
+		(if escape (set! title (scheme-escape title )))
 		(d-DirectivePut-header-override tag (logior DENEMO_OVERRIDE_TAGEDIT DENEMO_OVERRIDE_GRAPHIC))
 		(d-DirectivePut-header-display tag (string-append type " " fieldname ": " (html-escape title)))
 		(d-DirectivePut-header-postfix tag (string-append field " = \"" title "\"\n")))))
-	    (disp "Cancelled\n"))))))
+      (disp "Cancelled\n"))))
 
 ; SetScoreHeaderField sets a field in the score header
-(define (SetScoreHeaderField field)
-(let ((title "") (current "") (thematch #f) (tag ""))
+(define* (SetScoreHeaderField field  #:optional (title #f) (escape #t))
+(let ((current "") (thematch #f) (tag ""))
   (set! tag (string-append "Score" (string-capitalize field)))
   (set! current (d-DirectiveGet-scoreheader-postfix tag))
   (if (boolean? current)
@@ -442,11 +445,23 @@
 	;;(display thematch)
 	(if (regexp-match? thematch)
 	    (set! current (match:substring thematch 1)))))
-  (set! title (scheme-escape (d-GetUserInput (string-append "Score " field) 
-			      (string-append "Give a name for the " field " of the whole score") current)))
-  (d-DirectivePut-scoreheader-override tag (logior DENEMO_OVERRIDE_TAGEDIT DENEMO_OVERRIDE_GRAPHIC))
-  (d-DirectivePut-scoreheader-display tag (string-append field ": " title))
-  (d-DirectivePut-scoreheader-postfix tag (string-append field " = \"" title "\"\n"))))
+  (if (not title)
+    (begin 
+      (set! title  (d-GetUserInput (string-append "Score " field) 
+			      (string-append "Give a name for the " field " of the whole score") current #f))
+      (if title
+	(set! title (string-append "\"" title "\"")))))
+  (if title
+    (begin
+      (d-SetSaved #f)
+      (if (string-null? title)
+	      (d-DirectiveDelete-scoreheader tag)
+	      (begin
+		(if escape (set! title (scheme-escape title )))
+		(d-DirectivePut-scoreheader-override tag (logior DENEMO_OVERRIDE_TAGEDIT DENEMO_OVERRIDE_GRAPHIC))
+		(d-DirectivePut-scoreheader-display tag (string-append field ": " (html-escape title)))
+		(d-DirectivePut-scoreheader-postfix tag (string-append field " = " title "\n")))))
+	(disp "Cancelled\n"))))	
 
 (define (CreateButton tag label)
   (d-DirectivePut-score-override tag (logior DENEMO_OVERRIDE_MARKUP DENEMO_OVERRIDE_GRAPHIC))
@@ -959,7 +974,7 @@
 ;;User has two different options: insert an interval like m2 or p5 directly or give two notes.
 ;;Return value is a number for the ANS pillar of 5th.
 (define (AskForInterval)
-	(define interval (d-GetUserInput "Please enter a transpose interval" "Please enter a transpose interval or two notes in Lilypond syntax.\n\nExample: m2 minor second, M2 major second, p5 fifth, T tritone.\nOr:  c' e' for a major third.\nFor a complete list please read the manual." GlobalRememberInterval))
+	(define interval (d-GetUserInput (_"Please enter a transpose interval") (_ "Please enter a transpose interval or two notes in Lilypond syntax.\n\nExample: m2 minor second, M2 major second, p5 fifth, T tritone.\nOr:  c' e' for a major third.") GlobalRememberInterval))
 	(set! GlobalRememberInterval interval)
 	(if (ANS::IntervalGetSteps (string->symbol interval))
 		(ANS::IntervalGetSteps (string->symbol interval))
