@@ -195,8 +195,7 @@ typedef enum  action_type {
 typedef struct 
 {
   DenemoObjType type; /**< The type of object pointed to by the gpointer object field below */
-  gchar *user_string;/**< Holds user's original text parsed to generated this 
-			object OBSOLETE */
+  gchar *lilypond;/**< Holds lilypond generated to represent this object, empty until typesetting is called and out of date if the object has been modified since typesetting */
   gint basic_durinticks; /**< Duration of object including dotting but not tuplet/grace note effects. */
   gint durinticks; /**< Duration of object where 384 (PPQN) is a quarter note, includes any tuplet/grace note effects */
   gint starttick; /**< When the object occurs */ 
@@ -380,6 +379,8 @@ typedef struct DenemoPrefs
   gint zoom; /**< percent zoom of score area display  1-100 */
   gint system_height; /**< percent of display height per system  1-100 */
   gboolean cursor_highlight; /** Should the cursor be highlighted */
+  gboolean return_key_is_special; /** Should the Return key be treated as movable shortcut */
+  gboolean newbie; /** Give maximum help */
   gboolean progressbardecorations; /** TRUE if you want window decorations on progressbar */
   gboolean toolbar; /**< makes the toolbar visible */
   gboolean playback_controls; /**< makes the playback controls visible */
@@ -431,6 +432,11 @@ typedef struct DenemoPrefs
   gint dynamic_compression;/**< percent compression of dynamic range desired when listening to MIDI-in */
   gdouble display_refresh;/**< time in ms between refresh of display during playback */
   gint animation_steps;/** < number of steps to use animating the page turns during playback */
+  gint tooltip_timeout;/** < timeout before a tooltip appears */
+  gint tooltip_browse_timeout;/** < timeout before a tooltip appears in tooltip browse mode */
+  gint tooltip_browse_mode_timeout;/** < timeout before a tooltip browse mode is dropped*/
+
+    
   GString *pdfviewer; /**< PDF viewer */
   GString *imageviewer; /**< Image Viewer */
   GString *username; /**< Username for use on denemo.org website */
@@ -663,13 +669,17 @@ typedef struct DenemoScriptParam { /**< commands called by scripts use one of th
 } DenemoScriptParam;
 
 
-
-
-
-
 typedef struct DenemoScoreblock {
-  GString *scoreblock;/**< text of the scoreblock */
+  GString *lilypond;/**< text of the scoreblock */
   gboolean visible;/**< Whether the scoreblock should be used by default */
+  gboolean layout_sync;/**< Value of gui->layout_sync when the scoreblock was created */
+  GtkWidget *widget;/**< Widget to be placed in the Score Layout window for this scoreblock */
+  GList *staff_list;/**< List of staff frames contained in widget */
+  gchar *name;/**< name for this scoreblock */
+  gchar *uri;/**< uri for the output from printing this scoreblock */
+  guint32 id;/**< an id for this scoreblock generated from name, as a quick identifier */
+  gint movement;/**< Which movement the scoreblock outputs, 0 = all movements. Only used for standard scoreblocks */
+  gchar *partname; /**< Which part the scoreblock outputs, NULL = all parts. Only used for standard scoreblocks */
 } DenemoScoreblock;
 
 
@@ -881,7 +891,10 @@ typedef struct DenemoGUI
   paper paper;/*< Directives for the paper block of the score */
   GList *midi_events;/*< midi_events to be output at start of first track of each movement */
 
-  GList *custom_scoreblocks; /**< List of customized texts for LilyPond output, replaces standard score blocks, elements are DenemoScoreblock * */
+  GList *standard_scoreblocks; /**< List of automatically generated \score blocks for LilyPond output elements are DenemoScoreblock * */
+  GList *custom_scoreblocks; /**< List of customized  \score blocks for LilyPond output, elements are DenemoScoreblock * */
+  GtkWidget *score_layout; /**< The window in which custom_scoreblock widgets are placed */
+  guint layout_id; /**< cached value of the currently selected layout id */
   GList *callbacks;/**< scheme callbacks on deletion */
   gpointer lilystart, lilyend; /**<range of lilytext  */
   GString **target; /**< pointer to target string for modification in lilytext  */
@@ -897,7 +910,7 @@ typedef struct DenemoGUI
   guint changecount;/**< number of edits since score loaded */
   guint lilysync;/**< value of changecount when the Lily text was last refreshed */
 
- 
+  guint layout_sync;/**< value of changecount when the layout structure of the score was last changed, used to detect if a DenemoScoreblock is out of date */
   /* support for rhythm patterns */
   GList *rhythms;/**< list of RhythmPattern s */
   GList *currhythm; /**< currently in use element of rhythms */
@@ -925,6 +938,7 @@ typedef struct RhythmPattern
   GtkToolButton *button; /**< the button on the rhythm toolbar which invokes this rhythm */
   GList *clipboard;/**< a Denemo clipboard, used to create this patttern. */
   gchar *name;/**< a user-facing name for this pattern */
+  gchar *lilypond; /**< LilyPond syntax for this pattern */
 } RhythmPattern;
 
 
