@@ -428,8 +428,7 @@ gboolean
 swapmovements (GtkAction *action, gpointer param)
 {
   DenemoGUI  *gui = Denemo.gui;
-  if(!confirm_insertstaff_custom_scoreblock(gui))
-    return FALSE;
+  (void)signal_structural_change(gui);
   GList *this = g_list_find( gui->movements, gui->si);
   if(this->prev) {
     GList * prev = this->prev;
@@ -461,8 +460,7 @@ gboolean
 swapstaffs (GtkAction *action, gpointer param)
 {
   DenemoGUI  *gui = Denemo.gui;
-  if(!confirm_insertstaff_custom_scoreblock(gui))
-    return FALSE;
+  (void)signal_structural_change(gui);
   if (gui->si->currentstaff && gui->si->currentstaff->prev)
     {
       DenemoStaff *temp;
@@ -503,8 +501,7 @@ gboolean
 splitstaffs (GtkAction *action, gpointer param)
 {
   DenemoGUI  *gui = Denemo.gui;
-  if(!confirm_insertstaff_custom_scoreblock(gui))
-    return FALSE;
+
   if (gui->si->currentstaff && gui->si->currentstaff->next)
     {
       take_snapshot();
@@ -535,8 +532,7 @@ gboolean
 joinstaffs (GtkAction *action, gpointer param)
 {
   DenemoGUI  *gui = Denemo.gui;
-  if(!confirm_insertstaff_custom_scoreblock(gui))
-    return FALSE;
+
   if (gui->si->currentstaff && gui->si->currentstaff->prev)
     {
       take_snapshot();
@@ -1618,11 +1614,7 @@ notechange (DenemoScore * si, gboolean remove)
 	ret = (gboolean)(intptr_t)addtone (curmudelaobj, si->cursor_y/* mid_c_offset*/,
 		 si->cursoraccs[si->staffletter_y]/* enshift */, si->cursorclef /*dclef*/);
 
-      if (curmudelaobj->user_string)
-	{
-	  g_free (curmudelaobj->user_string);
-	  curmudelaobj->user_string = NULL;
-	}
+      
       if(Denemo.gui->last_source==INPUTKEYBOARD) {
 	DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
 
@@ -1709,11 +1701,7 @@ incrementenshift (DenemoGUI * gui, gint direction)
 			    si->curmeasurekey, si->curmeasureaccs);
       find_xes_in_measure (si, si->currentmeasurenum, si->cursortime1,
 			   si->cursortime2);
-      if (curmudelaobj->user_string)
-	{
-	  g_free (curmudelaobj->user_string);
-	  curmudelaobj->user_string = NULL;
-	}
+      
       if(Denemo.gui->last_source==INPUTKEYBOARD) {
 	DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
 
@@ -1743,11 +1731,7 @@ setenshift (DenemoScore * si, gint enshift)
       store_for_undo_change (si, curmudelaobj);
 
       changeenshift (curmudelaobj, si->cursor_y, enshift);
-      if (curmudelaobj->user_string)
-	{
-	  g_free (curmudelaobj->user_string);
-	  curmudelaobj->user_string = NULL;
-	}
+      
 
       if(Denemo.gui->input_source==INPUTKEYBOARD) {
 	DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
@@ -1787,11 +1771,7 @@ change_stem_directive (DenemoScore * si, enum stemdirections amount)
 	  break;
 	}
 
-      if (curmudelaobj->user_string)
-	{
-	  g_free (curmudelaobj->user_string);
-	  curmudelaobj->user_string = NULL;
-	}
+      
 
     }
 }
@@ -1821,11 +1801,7 @@ changedots (DenemoScore * si, gint amount)
       }
       changenumdots (curmudelaobj, amount);
 
-      if (curmudelaobj->user_string)
-	{
-	  g_free (curmudelaobj->user_string);
-	  curmudelaobj->user_string = NULL;
-	}
+      
     }
 }
 
@@ -2437,11 +2413,7 @@ toggle_begin_slur (DenemoGUI *gui)
 
       ((chord *) curmudelaobj->object)->slur_begin_p
 	= !((chord *) curmudelaobj->object)->slur_begin_p;
-      if (curmudelaobj->user_string)
-	{
-	  g_free (curmudelaobj->user_string);
-	  curmudelaobj->user_string = NULL;
-	}
+      
 
     }
 }
@@ -2459,12 +2431,6 @@ caution (DenemoScore * si)
   forceaccidentals (curmudelaobj);
   find_xes_in_measure (si, si->currentmeasurenum, si->cursortime1,
 		       si->cursortime2);
-
-  if (curmudelaobj->user_string)
-    {
-      g_free (curmudelaobj->user_string);
-      curmudelaobj->user_string = NULL;
-    }
 }
 
 /**
@@ -2485,11 +2451,7 @@ toggle_end_slur (DenemoGUI *gui)
 
       ((chord *) curmudelaobj->object)->slur_end_p
 	= !((chord *) curmudelaobj->object)->slur_end_p;
-      if (curmudelaobj->user_string)
-	{
-	  g_free (curmudelaobj->user_string);
-	  curmudelaobj->user_string = NULL;
-	}
+      
 
     }
 }
@@ -2509,11 +2471,7 @@ toggle_start_crescendo (DenemoGUI * gui)
     {
       ((chord *) curmudelaobj->object)->crescendo_begin_p
 	= !((chord *) curmudelaobj->object)->crescendo_begin_p;
-      if (curmudelaobj->user_string)
-	{
-	  g_free (curmudelaobj->user_string);
-	  curmudelaobj->user_string = NULL;
-	}
+      
 
     }
 }
@@ -2533,11 +2491,7 @@ toggle_end_crescendo (DenemoGUI *gui)
     {
       ((chord *) curmudelaobj->object)->crescendo_end_p
 	= !((chord *) curmudelaobj->object)->crescendo_end_p;
-      if (curmudelaobj->user_string)
-	{
-	  g_free (curmudelaobj->user_string);
-	  curmudelaobj->user_string = NULL;
-	}
+      
 
     }
 }
@@ -2557,11 +2511,7 @@ toggle_start_diminuendo (DenemoGUI *gui)
     {
       ((chord *) curmudelaobj->object)->diminuendo_begin_p
 	= !((chord *) curmudelaobj->object)->diminuendo_begin_p;
-      if (curmudelaobj->user_string)
-	{
-	  g_free (curmudelaobj->user_string);
-	  curmudelaobj->user_string = NULL;
-	}
+      
 
     }
 }
@@ -2581,11 +2531,7 @@ toggle_end_diminuendo (DenemoGUI *gui)
     {
       ((chord *) curmudelaobj->object)->diminuendo_end_p
 	= !((chord *) curmudelaobj->object)->diminuendo_end_p;
-      if (curmudelaobj->user_string)
-	{
-	  g_free (curmudelaobj->user_string);
-	  curmudelaobj->user_string = NULL;
-	}
+      
 
     }
 }
