@@ -188,23 +188,23 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
   DenemoObject *mudelaitem = (DenemoObject *) curobj->data;
 
   //g_print("draw obj %d %d\n", mudelaitem->x, y);
-  //this is the selection being given a blue background
+  //this is the selection being given a green background
   if(cr) if(itp->mark) {
     cairo_save(cr);
-    cairo_set_source_rgb( cr, 0.5, 0.5, 1.0 );
+    cairo_set_source_rgb( cr, 0.5, 1.0, 0.5 );
     cairo_rectangle (cr, x+mudelaitem->x, y, 20, 80 );
     cairo_fill(cr);
     cairo_restore(cr);
   }
   //g_print("%x %f %f %f\n", Denemo.gui->si->playingnow, Denemo.gui->si->playhead,  mudelaitem->earliest_time, mudelaitem->latest_time );
 
-  // draw playhead as green background
+  // draw playhead as yellowish background
 
  if( Denemo.gui->si->playingnow == mudelaitem)
   {
      if(cr) {
        cairo_save(cr);
-       cairo_set_source_rgb( cr, 0.5, 1.0, 0.5 );
+       cairo_set_source_rgb( cr, 0.8, 0.8, 0.0 );
        cairo_rectangle (cr, x+mudelaitem->x, y, 20, 80 );
        cairo_fill(cr);
        cairo_restore(cr);
@@ -245,7 +245,7 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
 
 	gint highest = draw_chord ( cr, curobj, x + mudelaitem->x, y,
 		     GPOINTER_TO_INT (itp->mwidthiterator->data),
-		     itp->curaccs, itp->mark);
+		     itp->curaccs, itp->mark, (si->currentobject == curobj));
 	if((thechord->highesty) < itp->highy)
 	  itp->highy  = thechord->highesty;
 	itp->highy = MIN(itp->highy, highest);
@@ -349,9 +349,14 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
       itp->tupletstart = itp->tuplety = 0;
       break;
     case LILYDIRECTIVE:
-      // if(si->markstaffnum) not available
+     {DenemoDirective *directive = mudelaitem->object;
       if(cr) draw_lily_dir(cr,
-		       x + mudelaitem->x, y, 0, 0, mudelaitem, itp->mark);  
+		       x + mudelaitem->x, y, 0, 0, mudelaitem, itp->mark, (si->currentobject == curobj));
+      if((directive->ty - 10) < itp->highy)
+	  itp->highy  = directive->ty - 10/* for height of text */;
+      if((directive->gy - 10) < itp->highy)
+	  itp->highy  = directive->gy - 10/* for height of text */;
+    }
       break;
     case CLEF:
       itp->clef = ((clef *) mudelaitem->object);
