@@ -122,8 +122,16 @@ draw_notehead (cairo_t *cr,
      in the chord.  */
   if (thenote->showaccidental)
     {
-      if(cr)draw_accidental (cr, xx - thenote->position_of_accidental,
+      if(cr) {
+	  draw_accidental (cr, xx - thenote->position_of_accidental,
 		       y + height, enshift);
+	  if(thenote->showaccidental==DENEMO_REMINDER)
+	      drawtext_cr (cr, "!", xx - thenote->position_of_accidental - 8.0, y+height, 22.0); 
+	  if(thenote->showaccidental==DENEMO_CAUTIONARY) {
+	      drawtext_cr (cr, "(", xx - thenote->position_of_accidental - 8.0, y+height, 22.0);
+	      drawtext_cr (cr, ")", xx - thenote->position_of_accidental + 6.0, y+height, 22.0);//there are actual widths in accwidths.h which could be used instead of 6.0
+	  }
+      }
       accs[pitch] = enshift;
     }
 
@@ -200,11 +208,11 @@ draw_ledgers (cairo_t *cr,
 
 /**
  * Draw the chord object on the score
- *
+ * returns the highest y value drawn at
  */
 gint
 draw_chord ( cairo_t *cr, objnode * curobj, gint xx, gint y,
-	    gint mwidth, gint * accs, gboolean selected)
+	    gint mwidth, gint * accs, gboolean selected, gboolean at_cursor)
 {
   gint highest = 0;
   static gunichar upstem_char[SMALLESTDURATION + 1] =
@@ -321,8 +329,17 @@ draw_chord ( cairo_t *cr, objnode * curobj, gint xx, gint y,
 	  }
 	}
 	if(directive->display) {
+	  #define MAXLEN (8)
+	  gchar c=0;//if it is a long string only show it all when cursor is on it
+	  if((!at_cursor) && directive->display->len>MAXLEN) {
+	    c=*(directive->display->str+MAXLEN);
+	    *(directive->display->str+MAXLEN) = 0;
+	  }
 	  drawnormaltext_cr (cr, directive->display->str, xx+directive->tx, y + ((thechord.highesty>-10)?-10:thechord.highesty) - 8 +count+directive->ty );
-	  highest = y + ((thechord.highesty>-10)?-10:thechord.highesty) - 8 +count+directive->ty;
+	  highest = y + ((thechord.highesty>-10)?-10:thechord.highesty) - 8 +count+directive->ty - 10/*for height of text */;
+	  if(c) {
+	  *(directive->display->str+MAXLEN) = c;
+	  }
 	}
 	count += 16;
       } //for each chord directive
@@ -529,7 +546,7 @@ if(!override_chord_graphic) {
       }
   /* End stemdown stuff */
   
-  draw_articulations (cr, thechord, xx, y); 
+  
   if(is_grace) cairo_restore(cr);
   draw_ledgers (cr, thechord.highesty, thechord.lowesty, xx, y,
 		headwidths[noteheadtype]);
@@ -543,204 +560,3 @@ return highest;
 
 
 
-/**
- * Draw the articulations on the score
- *
- */
-void
-draw_articulations (cairo_t * cr,
-		    chord thechord, gint xx, gint y)
-{
-
-  static gunichar options_char[25] = { 0x81, 0x82, 0x8a, 0x8a, 0x8c, 0x8f, 0x8d, 0x8e,
-	                               0x92, 0x93, 0xa1, 0x9f, 0x94, 0xaf, 0xae, 0xac, 
-				       0x98, 0xa0, 0x8a, 0x95, 0x89, 0xab, 0xa8, 0xb0,
-				       0xa7 };
-
-  static gunichar noteoptions_char[3] = { 0x9a, 0x99, 0xad };
-  static gunichar strings_char[2] = { 0x97, 0x96 };
-  static gunichar organ_char[4] = { 0x9b, 0x9c, 0x9d, 0x9e };
-
-  /* extra y position for staccato, accent, tenuto, fermata when stacked */
-  gint extra = 0;
-  GList *tmp;
-
-  /* Fermata, Accents, Staccato, tenuto stuff.  */
-
-  /* The following code ought to see some serious reorganization.
-     (It's another chunk of code that uses arrays in a situation
-     where arrays aren't elegant -- rather, they're just confusing.
-     And how 'bout some nesting of these if statements?)  */
-
-  /* Calculate the offset required when stacking symbols */
-  extra = calc_offset (thechord, thechord.is_stemup);
-
-  /* These rely on notehead position and stem-ends 
-   * Usually are above the stave except tenuto and 
-   * staccato
-   */
-  for (tmp = thechord.ornamentlist; tmp; tmp = tmp->next)
-    {
-#if 0
-      g_print ("ornament %d\n", *(enum ornament *) (tmp->data));
-#endif
-      if (*(enum ornament *) tmp->data == (enum ornament) STACCATO)
-	drawfetachar_cr (cr, options_char[4],
-			   xx + NOTEHEAD_WIDTH / 2,
-			   y + extra);
-      if (*(enum ornament *) tmp->data == (enum ornament) TENUTO)
-	drawfetachar_cr (cr,
-			   options_char[5], xx,
-			   y + extra);
-      if (*(enum ornament *) tmp->data == (enum ornament) STACCATISSIMO)
-	drawfetachar_cr (cr, options_char[6],
-			   xx + NOTEHEAD_WIDTH / 2,
-			   y + extra);
-
-      if (*(enum ornament *) tmp->data == (enum ornament) D_ACCENT)
-	drawfetachar_cr (cr, options_char[2],
-			   xx + 2, y + extra);
-
-      else if (*(enum ornament *) tmp->data == (enum ornament) MARCATO)
-	drawfetachar_cr (cr, options_char[8],
-			   xx + 2, y + extra);
-
-
-      /* 
-       * Always should appear above the note(s) they
-       * effect.
-       */
-      if (*(enum ornament *) tmp->data == (enum ornament) FERMATA)
-	drawfetachar_cr (cr,
-			   options_char[0], xx - FERMATA_WIDTH / 4,
-			   y + extra);
-      if (*(enum ornament *) tmp->data == (enum ornament) CODA)
-	drawfetachar_cr (cr,
-			   options_char[10], xx - CODA_WIDTH / 4,
-			   y + extra);
-      if (*(enum ornament *) tmp->data == (enum ornament) TRILL)
-	drawfetachar_cr (cr,
-			   noteoptions_char[0], xx - TRILL_WIDTH / 4,
-			   y + extra);
-
-      else if (*(enum ornament *) tmp->data == (enum ornament) TURN)
-	drawfetachar_cr (cr,
-			   noteoptions_char[1], xx - TURN_WIDTH / 4,
-			   y + extra);
-
-      else if (*(enum ornament *) tmp->data == (enum ornament) MORDENT)
-	drawfetachar_cr (cr,
-			   noteoptions_char[2], xx - MORDENT_WIDTH / 4,
-			   y + extra);
-
-      if (*(enum ornament *) tmp->data == (enum ornament) DBOW)
-	drawfetachar_cr (cr,
-			   strings_char[0], xx, y + extra);
-      else if (*(enum ornament *) tmp->data == (enum ornament) UBOW)
-	drawfetachar_cr (cr,
-			   strings_char[1], xx, y + extra);
-
-      if (*(enum ornament *) tmp->data == (enum ornament) RHEEL)
-	{
-	  drawfetachar_cr (cr,
-			     organ_char[1], xx, y + extra);
-	}
-      else if (*(enum ornament *) tmp->data == (enum ornament) LHEEL)
-	{
-	  drawfetachar_cr (cr,
-			     organ_char[0], xx, y + extra);
-	}
-
-      if (*(enum ornament *) tmp->data == (enum ornament) RTOE)
-	{
-	  drawfetachar_cr (cr,
-			     organ_char[3], xx, y + extra);
-	}
-      else if (*(enum ornament *) tmp->data == (enum ornament) LTOE)
-	{
-	  drawfetachar_cr (cr,
-			     organ_char[2], xx, y + extra);
-	}
-      if (*(enum ornament *) tmp->data == (enum ornament) D_ARPEGGIO)
-	drawfetachar_cr (cr,
-			   options_char[24], xx, y + extra);
-
-      if (*(enum ornament *) tmp->data == (enum ornament) UPPRALL)
-	drawfetachar_cr (cr, options_char[23],
-			   xx, y + extra);
-
-      if (*(enum ornament *) tmp->data == (enum ornament) FLAGEOLET)
-	drawfetachar_cr (cr, options_char[11],
-			   xx, y + extra);
-      if (*(enum ornament *) tmp->data == (enum ornament) OPEN)
-	drawfetachar_cr (cr, options_char[12],
-			   xx, y + extra);
-      if (*(enum ornament *) tmp->data == (enum ornament) PRALLMORDENT)
-	drawfetachar_cr (cr, options_char[13],
-			   xx, y + extra);
-      if (*(enum ornament *) tmp->data == (enum ornament) PRALLPRALL)
-	drawfetachar_cr (cr, options_char[14],
-			   xx, y + extra);
-      if (*(enum ornament *) tmp->data == (enum ornament) PRALL)
-	drawfetachar_cr (cr, options_char[15],
-			   xx, y + extra);
-      if (*(enum ornament *) tmp->data == (enum ornament) REVERSETURN)
-	drawfetachar_cr (cr, options_char[16],
-			   xx, y + extra);
-      if (*(enum ornament *) tmp->data == (enum ornament) SEGNO)
-	drawfetachar_cr (cr, options_char[17],
-			   xx, y + extra);
-      if (*(enum ornament *) tmp->data == (enum ornament) SFORZATO)
-	drawfetachar_cr (cr, options_char[18],
-			   xx, y + extra);
-      if (*(enum ornament *) tmp->data == (enum ornament) STOPPED)
-	drawfetachar_cr (cr, options_char[19],
-			   xx, y + extra);
-      if (*(enum ornament *) tmp->data == (enum ornament) THUMB)
-	drawfetachar_cr (cr, options_char[20],
-			   xx, y + extra);
-      if (*(enum ornament *) tmp->data == (enum ornament) TRILLELEMENT)
-	drawfetachar_cr (cr, options_char[21],
-			   xx, y + extra);
-      if (*(enum ornament *) tmp->data == (enum ornament) TRILL_ELEMENT)
-	drawfetachar_cr (cr, options_char[22],
-			   xx, y + extra);
-
-    }				//end for loop
-
-}
-
-/** 
- * Calculate the offset required for the given ornament
- *
- */
-gint
-calc_offset (chord thechord, gint stemdir)
-{
-  gint offset = 0;
-  GList *tmp;
-
-  for (tmp = thechord.ornamentlist; tmp; tmp = tmp->next)
-    {
-      if (*(enum ornament *) tmp->data == (enum ornament) FERMATA ||
-	  *(enum ornament *) tmp->data == (enum ornament) TURN ||
-	  *(enum ornament *) tmp->data == (enum ornament) TRILL ||
-	  *(enum ornament *) tmp->data == (enum ornament) MORDENT)
-	offset = -LINE_SPACE - 7;
-      else if (( *(enum ornament *) tmp->data == (enum ornament) STACCATO ||
-	         *(enum ornament *) tmp->data == (enum ornament) TENUTO      )
-	         && stemdir)
-	offset = thechord.lowesty + 10;
-      else if (*(enum ornament *) tmp->data == (enum ornament) STACCATO ||
-	       *(enum ornament *) tmp->data == (enum ornament) TENUTO)
-	offset = thechord.highesty - 10;
-      else if (*(enum ornament *) tmp->data == (enum ornament) D_ACCENT
-	       && stemdir)
-	offset = thechord.lowesty + 10;
-      else if (*(enum ornament *) tmp->data == (enum ornament) MARCATO ||
-	       *(enum ornament *) tmp->data == (enum ornament) D_ACCENT)
-	offset = -thechord.highesty - 6;
-    }
-
-  return offset;
-}
