@@ -9,6 +9,7 @@
 
 #include <gtk/gtk.h>
 #include <stdio.h>
+#define TAB "        "
 
 void exportlilypond (gchar * thefilename,  DenemoGUI *gui, gboolean all_movements);
 
@@ -28,4 +29,14 @@ void delete_lily_cb (GtkAction *action, gpointer param);
 void set_lily_error(gint line, gint column, DenemoGUI *gui);
 void highlight_lily_error(DenemoGUI *gui);
 gboolean goto_lilypond_position(gint line, gint column);
+
+
+void set_initiate_scoreblock(DenemoScore *si, GString *scoreblock);
+gchar *get_lilypond_for_clef(clef *theclef);
+gchar *get_lilypond_for_keysig(struct keysig *key);
+gchar *get_lilypond_for_timesig(timesig *time);
+gchar *get_lilypond_paper(void);
+const gchar *get_prevailing_clef_as_lilypond(void);
+const gchar *get_prevailing_keysig_as_lilypond(void);
+const gchar *get_prevailing_timesig_as_lilypond(void);
 #endif
