@@ -601,8 +601,8 @@ void newVoiceProps (xmlNodePtr parentElem, xmlNsPtr ns, DenemoStaff *curStaffStr
 	  
     if(curStaffStruct->voice_directives)
 	    newDirectivesElem(curElem, ns,curStaffStruct->voice_directives, "voice-directives");
-      if(curStaffStruct->clef.directives)
-	    newDirectivesElem(curElem, ns,curStaffStruct->voice_directives, "clef-directives");
+    if(curStaffStruct->clef.directives)
+	    newDirectivesElem(curElem, ns,curStaffStruct->clef.directives, "clef-directives");
 }
 /**
  * Output a notehead element of the form:
@@ -767,9 +767,16 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 
   GList *custom;
   for(custom=g_list_last(gui->custom_scoreblocks);custom;custom=custom->prev) {
-    xmlNewTextChild (scoreElem, ns, (xmlChar *)"custom_scoreblock", (xmlChar *)((GString*)(((DenemoScoreblock*)custom->data)->scoreblock)->str));
-    if(((DenemoScoreblock*)custom->data)->visible)
-      xmlNewChild (scoreElem, ns, (xmlChar *)"visible_scoreblock", NULL);
+    GString *lilypond = (GString*)(((DenemoScoreblock*)custom->data)->lilypond);
+    if(lilypond==NULL) refresh_lilypond((DenemoScoreblock*)custom->data);
+    lilypond = (GString*)(((DenemoScoreblock*)custom->data)->lilypond);
+    if(lilypond) {
+      xmlNodePtr scoreblockElem = xmlNewTextChild (scoreElem, ns, (xmlChar *)"custom_scoreblock", (xmlChar *)(lilypond->str));
+      if(((DenemoScoreblock*)custom->data)->uri)
+	  xmlSetProp (scoreblockElem, (xmlChar *)"scoreblock_uri",  (xmlChar *)((DenemoScoreblock*)custom->data)->uri);
+    }
+    else
+      g_warning("Custom Scoreblock with no LilyPond text");
   }
   //  if(gui->custom_prolog && gui->custom_prolog->len)
   //   xmlNewChild (scoreElem, ns, "custom_prolog", (xmlChar *)gui->custom_prolog->str);
@@ -1045,77 +1052,7 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
   		    }
 
 
-		  /* Output all the decorations. */
 
-		  if ((thechord)->ornamentlist)//backward compatibility
-		    {
-		      GList *tmp;
-		      push_position();
-		      goto_movement_staff_obj (NULL, 1+g_list_index(gui->movements, si), 1+g_list_position(si->thescore, curStaff), 1+g_list_position(curStaffStruct->measures, curMeasure), 1+g_list_position(curMeasure->data, curObjNode));
-		      for (tmp = (thechord)->ornamentlist;
-			   tmp; tmp = tmp->next)
-			{
-			 
-			  if (*(enum ornament *) tmp->data == STACCATO)
-			    call_out_to_guile("(d-ToggleStaccato)");
-			  if (*(enum ornament *) tmp->data == D_ACCENT)
-			    call_out_to_guile("(d-Toggleaccent)");
-			  if (*(enum ornament *) tmp->data == FERMATA)
-			    call_out_to_guile("(d-Togglefermata)");
-			  if (*(enum ornament *) tmp->data == TENUTO)
-			    call_out_to_guile("(d-Toggletenuto)");
-			  if (*(enum ornament *) tmp->data == TRILL)
-			    call_out_to_guile("(d-ToggleTrill)");
-			  if (*(enum ornament *) tmp->data == TURN)
-			    call_out_to_guile("(d-Toggleturn)");
-			  if (*(enum ornament *) tmp->data == MORDENT)
-			    call_out_to_guile("(d-Togglemordent)");
-			  if (*(enum ornament *) tmp->data == STACCATISSIMO)
-			    call_out_to_guile("(d-Staccatissimo)");
-			  if (*(enum ornament *) tmp->data == MARCATO)
-			    call_out_to_guile("(d-Togglemarcato)");
-			  if (*(enum ornament *) tmp->data == UBOW)
-			    call_out_to_guile("(d-Toggleup-bow)");
-			  if (*(enum ornament *) tmp->data == DBOW)
-			    call_out_to_guile("(d-Toggledown-bow)");
-			  if (*(enum ornament *) tmp->data == RHEEL)
-			    call_out_to_guile("(d-Toggleright-heel)");
-			  if (*(enum ornament *) tmp->data == LHEEL)
-			    call_out_to_guile("(d-Toggleleft-heel)");
-			  if (*(enum ornament *) tmp->data == RTOE)
-			    call_out_to_guile("(d-Toggleright-toe)");
-			  if (*(enum ornament *) tmp->data == LTOE)
-			    call_out_to_guile("(d-Toggleleft-toe)");
-			  if (*(enum ornament *) tmp->data == CODA)
-			    call_out_to_guile("(d-Togglecoda)");
-			  if (*(enum ornament *) tmp->data == FLAGEOLET)
-			    call_out_to_guile("(d-Toggleflageolet)");
-			  if (*(enum ornament *) tmp->data == OPEN)
-			    call_out_to_guile("(d-Toggleopen)");
-			  if (*(enum ornament *) tmp->data == PRALLMORDENT)
-			    call_out_to_guile("(d-Toggleprallmordent)");
-			  if (*(enum ornament *) tmp->data == PRALLPRALL)
-			    call_out_to_guile("(d-Toggleprallprall)");
-			  if (*(enum ornament *) tmp->data == PRALL)
-			    call_out_to_guile("(d-Toggleprall)");
-			  if (*(enum ornament *) tmp->data == REVERSETURN)
-			    call_out_to_guile("(d-Togglereverseturn)");
-			  if (*(enum ornament *) tmp->data == SEGNO)
-			    call_out_to_guile("(d-Togglesegno)");
-			  if (*(enum ornament *) tmp->data == SFORZATO)
-			    call_out_to_guile("(d-Togglesforzato)");
-			  if (*(enum ornament *) tmp->data == STOPPED)
-			    call_out_to_guile("(d-Togglestopped)");
-			  if (*(enum ornament *) tmp->data == THUMB)
-			    call_out_to_guile("(d-Togglethumb)");
-			  if (*(enum ornament *) tmp->data == UPPRALL)
-			    call_out_to_guile("(d-Toggleupprall)");
-			  if (*(enum ornament *) tmp->data == D_ARPEGGIO)
-			    call_out_to_guile("(d-Togglearpeggio)");
-			}
-		      pop_position();
-		      (thechord)->ornamentlist = NULL;
-		    }
 		    /* Output the DenemoDirectives on the chord */
 		  if((thechord)->directives) {
 		    newDirectivesElem(objElem, ns,  (thechord)->directives, "directives");
