@@ -53,11 +53,6 @@ apply_fakechord (chord * ch, gchar * fig)
       chord *mych = (chord *) mud->object;
       GString *mygstr = (GString *) mych->fakechord;
       g_string_assign (mygstr, fig);	/* FIXME g_free(mygstr->str) first ? */
-      if (mud->user_string)
-	{
-	  g_free (mud->user_string);
-	  mud->user_string = NULL;
-	}
     }
 }
 
@@ -157,8 +152,10 @@ insertfakechord (GtkWidget * widget, gpointer data)
 		si->currentobject ? (DenemoObject *) si->currentobject->data : NULL;
 	    }
 	  while ((curObj != NULL) && (curObj->type != CHORD));
-
-	  si->has_fakechords = (gpointer)TRUE;//&null_info;
+	  if(!si->has_fakechords) {
+	    si->has_fakechords = (gpointer)TRUE;
+	    signal_structural_change(gui);
+	  }
 	  score_status(gui, TRUE);
 	  return TRUE;
   }
