@@ -678,8 +678,7 @@ file_import_musicxml_with_check (GtkAction * action, DenemoScriptParam * param)
 #define ADD(insertion_strategy)\
   DenemoGUI *gui = Denemo.gui;\
   GET_1PARAM(action, param, filename);\
-  if(filename==NULL && !confirm_insertstaff_custom_scoreblock(gui))\
-    return;\
+  (void)signal_structural_change(gui);\
   param->status = !file_open(gui, FALSE, insertion_strategy, filename);\
   score_status(gui, TRUE);\
 
@@ -771,12 +770,12 @@ update_preview_cb(GtkFileChooser *file_chooser, gpointer data){
   thumb_filename = large_thumbnail_name(selection_filename); 
   pixbuf = gdk_pixbuf_new_from_file_at_size(thumb_filename, 512,512, NULL);
   have_preview = (pixbuf !=NULL);
-  
+#ifdef DEBUG  
   printf("\n# %s for %s thumbnail = %s\n",have_preview? "We have a thumbnail generated":
 				     "We have not yet generated a thumbnail",
  				     selection_filename,
 				     thumb_filename);
-  
+#endif  
   g_free(selection_filename);
   g_free(thumb_filename);
 
@@ -910,7 +909,7 @@ file_saveaswrapper (GtkAction * action, DenemoScriptParam *param)
  * Wrapper function to save the current file as template
  */
 void
-template_save (GtkAction * action, gpointer param)
+template_save (GtkAction * action, DenemoScriptParam *param)
 {
   DenemoGUI *gui = Denemo.gui;
   init_local_path();
@@ -923,7 +922,7 @@ template_save (GtkAction * action, gpointer param)
  * Wrapper function to save the current file as a copy
  */
 void
-file_copy_save (GtkAction * action, gpointer param)
+file_copy_save (GtkAction * action, DenemoScriptParam *param)
 {
   DenemoGUI *gui = Denemo.gui;
   init_local_path();
@@ -935,7 +934,7 @@ file_copy_save (GtkAction * action, gpointer param)
  *
  */
 void
-file_savewrapper (GtkAction * action, gpointer param)
+file_savewrapper (GtkAction * action, DenemoScriptParam *param)
 {
   DenemoGUI *gui = Denemo.gui;
   file_save (NULL, gui);
@@ -1047,30 +1046,34 @@ file_saveas (DenemoGUI * gui, DenemoSaveType  template)
  *
  */
 void
-file_newwrapper (GtkAction * action, gpointer param)
+file_newwrapper (GtkAction * action, DenemoScriptParam *param)
 {
+  DenemoScriptParam dummy;
+  dummy.string=NULL;
+  if(param==NULL)
+    param = &dummy;
   DenemoGUI *gui = Denemo.gui;
   if (gui->notsaved)
     {
-      if (confirmbox (gui))
-	{
-	  deletescore(NULL, gui);
-	}
-      else
-	return;
+      if (confirmbox (gui)) {
+          deletescore(NULL, gui);
+      }
+      else {
+        param->status = FALSE;
+        return;
+      }
     }
-  else
-    {
+  else {
       deletescore(NULL, gui);
-    }
-  //open_user_default_template(REPLACE_SCORE);
-  load_initdotdenemo();
+  }
   set_enharmonic_position(0);
   if(Denemo.printarea) 
     g_object_set_data(G_OBJECT(Denemo.printarea), "printviewupdate", (gpointer)G_MAXUINT);
   score_status(gui, FALSE);
+  param->status = TRUE;
 }
 
+
 /* open_user_default_template
  * open the user's standard template if there is one
  * @return 0 for success non zero for failure
@@ -1086,24 +1089,6 @@ open_user_default_template(ImportType type) {
   return ret;
 }
 
-/* load local init.denemo or failing that system wide template file init.denemo*/
-void
-load_initdotdenemo(void) {
-   gchar *init_file;
-
-   init_file = g_build_filename(locatedotdenemo (), "actions", "init.denemo", NULL);
-   if(g_file_test(init_file, G_FILE_TEST_EXISTS)) {
-     if(open_for_real (init_file, Denemo.gui, TRUE, REPLACE_SCORE))
-       g_warning("Could not open %s\n", init_file);
-   } else {
-     g_free(init_file);
-     init_file = g_build_filename(get_data_dir (), "actions", "init.denemo", NULL);
-     if (open_for_real (init_file, Denemo.gui, TRUE, REPLACE_SCORE) == -1)
-       g_warning("Denemo initialization file %s not found", init_file);
-     g_free(init_file);
-   }
-   deleteSchemeText();
-} 
 
 /**
  * Creates dialog to say that the chosen filename already exists
@@ -1135,7 +1120,7 @@ replace_existing_file_dialog (const gchar * filename,
  * Save parts to individual files
  */
 void
-file_savepartswrapper (GtkAction * action, gpointer param)
+file_savepartswrapper (GtkAction * action, DenemoScriptParam *param)
 {
   DenemoGUI *gui = Denemo.gui;
   if (gui->filename->len==0)
@@ -1190,7 +1175,7 @@ selection_received (GtkClipboard *clipboard, const gchar *text, gpointer data) {
 }
 
 void
-paste_clipboard(GtkAction * action, gpointer param) {
+paste_clipboard(GtkAction * action, DenemoScriptParam *param) {
   if(Denemo.gui != g_list_last(Denemo.guis)->data) {
     warningdialog("Can only paste LilyPond text into the last tab, sorry");
     return;
