@@ -21,6 +21,7 @@
 #include "texteditors.h"
 #include "lilydirectives.h"
 #include "calculatepositions.h"
+#include "scorelayout.h"
 #include <string.h>
 
 
@@ -1068,128 +1069,6 @@ parseDynamic (xmlNodePtr dynamicElem, DenemoObject * curobj)
 
 }
 
-/**
- * Parse the given <decoration> element into the given chord-type DenemoObject.
- */
-static void
-parseDecoration (xmlNodePtr decorationElem, DenemoObject * chordObj)
-{
-  gchar *decorationType = (gchar *) xmlGetProp (decorationElem,
-						(xmlChar *) "type");
-
-  if (decorationType == NULL)
-    g_warning ("No \"type\" attribute present on <decoration> element; "
-	       "ignoring");
-  else if (strcmp (decorationType, "accent") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (D_ACCENT,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "down-bow") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (DBOW, ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "fermata") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (FERMATA,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "left-heel") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (LHEEL,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "left-toe") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (LTOE, ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "marcato") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (MARCATO,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "mordent") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (MORDENT,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "right-heel") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (RHEEL,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "right-toe") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (RTOE, ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "staccato") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (STACCATO,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "staccatissimo") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (STACCATISSIMO,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "tenuto") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (TENUTO,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "trill") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (TRILL,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "turn") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (TURN, ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "up-bow") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (UBOW, ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "coda") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (CODA, ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "flageolet") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (FLAGEOLET,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "open") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (OPEN, ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "prallmordent") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (PRALLMORDENT,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "prallprall") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (PRALLPRALL,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "prall") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (PRALL,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "reverseturn") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (REVERSETURN,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "segno") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (SEGNO,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "sforzato") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (SFORZATO,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "stopped") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (STOPPED,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "thumb") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (THUMB,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "upprall") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (UPPRALL,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else if (strcmp (decorationType, "arpeggio") == 0)
-    ((chord *) chordObj->object)->ornamentlist =
-      insert_ornament_list (D_ARPEGGIO,
-			    ((chord *) chordObj->object)->ornamentlist);
-  else
-    g_warning ("Unknown decoration type \"%s\"; ignoring", decorationType);
-
-  g_free (decorationType);
-}
 
 static GdkPixbuf *
 parseSource(xmlNodePtr parentElem, xmlNsPtr ns) {
@@ -1306,21 +1185,6 @@ parseChord (xmlNodePtr chordElem, xmlNsPtr ns,
 	  {
 	    parseDynamic (childElem, chordObj);
 	  }
-	else if (ELEM_NAME_EQ (childElem, "decorations"))
-	  {
-	    FOREACH_CHILD_ELEM (grandchildElem, childElem)
-	    {
-	      if (grandchildElem->ns == ns
-		  && ELEM_NAME_EQ (grandchildElem, "decoration"))
-		{
-		  parseDecoration (grandchildElem, chordObj);
-		}
-	      else
-		{
-		  ILLEGAL_ELEM ("decorations", grandchildElem);
-		}
-	    }
-	  }
 	else if (ELEM_NAME_EQ (childElem, "tie"))
 	  {
 	    /* For now at least, ignore the "to" attribute. */
@@ -3256,11 +3120,16 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
 		    gchar *tmp = (gchar *) xmlNodeListGetString (childElem->doc,
 								 childElem->
 								 xmlChildrenNode, 1);
+		    gchar *uri = (gchar *) xmlGetProp (childElem, (xmlChar *) "scoreblock_uri");
 		    if (tmp != NULL)
 		      {
-			DenemoScoreblock *sb = g_malloc0 (sizeof(DenemoScoreblock));
-			sb->scoreblock = g_string_new(tmp);
+			DenemoScoreblock *sb = get_scoreblock_for_lilypond(tmp); 
+			GtkWidget *notebook = get_score_layout_notebook(gui);
+			GtkWidget *label = gtk_label_new(sb->name);
+			gtk_notebook_prepend_page(GTK_NOTEBOOK(notebook), sb->widget, label);
+			gtk_widget_show_all(notebook);
 			gui->custom_scoreblocks = g_list_prepend(gui->custom_scoreblocks, sb);
+			sb->uri = uri;//do not free uri
 			g_free (tmp);
 		      }
 		  } else
