@@ -4,7 +4,6 @@
  */
 
 #include <string.h>
-
 #include "kbd-custom.h"
 #include "keyresponses.h"
 #include "articulations.h"
@@ -13,7 +12,9 @@
 #include "tupletops.h"
 #include "view.h"
 #include "commandfuncs.h"
-
+#if GTK_MAJOR_VERSION==3
+  #include <gdk/gdkkeysyms-compat.h> //FIXME Look for something more gtk3 like
+#endif
 static GdkEventKey ** divert_key_event;/* Non null if key events are being intercepted by a function
 					* (which is running a gtk_mail_loop() for this reason).
 					* return TRUE if a key press successfully captured
@@ -913,220 +914,6 @@ remove_dot_key (DenemoGUI * gui)
 }
 
 
-void
-add_accent (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-
-  /* Equals - toggle whether this note is tied */
-  addornament (curmudelaobj, D_ACCENT);
-  /* if (curmudelaobj && curmudelaobj->type == CHORD &&
-     ((chord *) curmudelaobj->object)->notes)
-     ((chord *)curmudelaobj->object)->ornamentlist = 
-     insert_ornament_list(D_ACCENT,
-     ((chord *)curmudelaobj->object)->ornamentlist); */
-
-}
-
-void
-add_fermata (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-
-  /* Equals - toggle whether this note is tied */
-  addornament (curmudelaobj, FERMATA);
-
-
-}
-
-void
-add_staccato (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-
-  /* Equals - toggle whether this note is tied */
-  addornament (curmudelaobj, STACCATO);
-
-
-
-}
-
-void
-add_tenuto (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-
-  /* Equals - toggle whether this note is tied */
-  addornament (curmudelaobj, TENUTO);
-}
-
-
-void
-add_trill (DenemoGUI * gui)
-{
-/*  note *curr;*/
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-
-  addornament (curmudelaobj, TRILL);
-
-}
-
-void
-add_turn (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, TURN);
-}
-
-void
-add_mordent (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, MORDENT);
-
-}
-
-void
-add_staccatissimo (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, STACCATISSIMO);
-
-}
-
-void
-add_coda (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, CODA);
-
-
-}
-
-
-void
-add_flageolet (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-
-  addornament (curmudelaobj, FLAGEOLET);
-
-}
-
-void
-add_open (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, OPEN);
-
-}
-
-void
-add_prallmordent (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, PRALLMORDENT);
-}
-
-void
-add_prallprall (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, PRALLPRALL);
-}
-
-void
-add_prall (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, PRALL);
-}
-
-void
-add_reverseturn (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, REVERSETURN);
-}
-
-void
-add_segno (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, SEGNO);
-}
-
-void
-add_sforzato (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, SFORZATO);
-}
-
-void
-add_stopped (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, STOPPED);
-}
-
-void
-add_thumb (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, THUMB);
-}
-
-void
-add_trillelement (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, TRILLELEMENT);
-}
-
-void
-add_trill_element (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, TRILLELEMENT);
-}
-
-void
-add_upprall (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, UPPRALL);
-}
-
-void
-add_arpeggio (DenemoGUI * gui)
-{
-  DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
-  addornament (curmudelaobj, D_ARPEGGIO);
-}
 
 
 
