@@ -63,200 +63,9 @@ gboolean uses_default_commandset(void) {
 
 
 
-static const GtkStockItem denemo_stock_items[] = {
-  {"denemo-staccato", N_("Staccato"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-staccatissimo", N_("Staccatissimo"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-marcato", N_("Marcato"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-accent", N_("Accent"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-fermata", N_("Fermata"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-coda", N_("Coda"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-tenuto", N_("Tenuto"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-turn", N_("Turn"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-reverse-turn", N_("Reverse turn"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-trill", N_("Trill"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-mordent", N_("Mordent"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-up-bow", N_("Up bow"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-down-bow", N_("Down bow"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-rheel", N_("Right heel"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-lheel", N_("Left heel"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-ltoe", N_("Left toe"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-rtoe", N_("Right toe"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-whole-note", N_("Whole note"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-half-note", N_("Half note"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-quarter-note", N_("Quarter note"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-eight-note", N_("Eight note"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-sixteenth-note", N_("Sixteenth note"), (GdkModifierType) 0, 0,
-   NULL},
-  {"denemo-whole-rest", N_("Whole rest"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-half-rest", N_("Half rest"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-quarter-rest", N_("Quarter rest"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-eight-rest", N_("Eigth rest"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-sixteenth-rest", N_("Sixteenth rest"), (GdkModifierType) 0, 0,
-   NULL},
-  {"denemo-prall", N_("Prall"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-flageolet", N_("Flageolet"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-prallmordent", N_("PrallMordent"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-prallprall", N_("PrallPrall"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-open", N_("Open"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-segno", N_("Segno"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-stopped", N_("Stopped"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-thumb", N_("Thumb"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-upprall", N_("Upprall"), (GdkModifierType) 0, 0, NULL},
-  {"denemo-arpeggio", N_("Arpeggio"), (GdkModifierType) 0, 0, NULL}
-};
 
-static void
-register_stock_icon (GtkIconFactory * icon_factory, const gchar * stock_id,
-                     const gchar * file)
-{
-  static gboolean warned;
-  GtkIconSet *icon_set;
-  GdkPixbuf *pixbuf;
-  GError *error = NULL;
-  gchar *path = g_build_filename (get_data_dir (), "pixmaps", file, NULL);
 
-  g_debug ("path is %s\n", path);
-  pixbuf = gdk_pixbuf_new_from_file (path, &error);
-  if(!warned)
-  if(error != NULL)
-    {
-      g_warning (_("Could not load specified pixbuf:\n%s\n"),
-                 error->message);
-      g_error_free (error);
-      if(first_time_user())
-	g_warning("some icons will not display properly, but program will run ok.");
-      warned = TRUE;
-    }
-  if(pixbuf != NULL) {
-    icon_set = gtk_icon_set_new_from_pixbuf (pixbuf);
-    g_object_unref (pixbuf);
-    gtk_icon_factory_add (icon_factory, stock_id, icon_set);
-    g_free (path);
-  } 
-  //FIXME  path may leak
-}
 
-// removes the accel of a standard stock item. We use this because we want to
-// handle all the keybindings in denemo's keymap.
-// Also, removes the _ in the label of the accel so that no mnemonic is defined
-static void
-clean_stock_item(const gchar *stock_id)
-{
-    gint i, j;
-    GtkStockItem stock;
-    gchar *label;
-    if (gtk_stock_lookup(stock_id, &stock)) {
-        label = g_strdup(stock.label);
-        if (stock.label != NULL) {
-            i = 0;
-            j = 0;
-            while (stock.label[i]) {
-                if (stock.label[i] == '_')
-                    i++;
-                else {
-                    label[j] = stock.label[i];
-                    i++;
-                    j++;
-                }
-            }
-            label[j] = '\0';
-        }
-        stock.label = label;
-        stock.keyval = 0;
-        stock.modifier = 0;
-        gtk_stock_add(&stock, 1);
-        g_free(label);
-    }
-}
-
-static void
-register_stock_items ()
-{
-  GtkIconFactory *icon_factory;
-
-  /* Load stock items that denemo defines*/
-  gtk_stock_add_static (denemo_stock_items,
-                        G_N_ELEMENTS (denemo_stock_items));
-
-  /* Load stock icons for the new stock items*/
-  icon_factory = gtk_icon_factory_new ();
-  gtk_icon_factory_add_default (icon_factory);
-  register_stock_icon (icon_factory, "denemo-staccato", "staccato.svg");
-  register_stock_icon (icon_factory, "denemo-staccatissimo",
-		       "staccatissimo.svg");
-  register_stock_icon (icon_factory, "denemo-marcato", "marcato.svg");
-  register_stock_icon (icon_factory, "denemo-accent", "accent.svg");	 
-  register_stock_icon (icon_factory, "denemo-fermata", "fermata.svg");
-  register_stock_icon (icon_factory, "denemo-tenuto", "tenuto.svg");
-  register_stock_icon (icon_factory, "denemo-turn", "turn.svg");
-  register_stock_icon (icon_factory, "denemo-reverse-turn",
-		       "reverse-turn.svg");	 
-  register_stock_icon (icon_factory, "denemo-trill", "trill.svg");
-  register_stock_icon (icon_factory, "denemo-mordent", "mordent.svg");
-  register_stock_icon (icon_factory, "denemo-up-bow", "upbow.svg");
-  register_stock_icon (icon_factory, "denemo-down-bow", "downbow.svg");
-	 
-  register_stock_icon (icon_factory, "denemo-rheel", "rheel.svg");
-  register_stock_icon (icon_factory, "denemo-lheel", "lheel.svg");
-  register_stock_icon (icon_factory, "denemo-rtoe", "rtoe.svg");
-  register_stock_icon (icon_factory, "denemo-ltoe", "ltoe.svg");
-	 
-  register_stock_icon (icon_factory, "denemo-whole-note", "icon-note-0.svg");
-  register_stock_icon (icon_factory, "denemo-half-note", "icon-note-1.svg");
-  register_stock_icon (icon_factory, "denemo-quarter-note",
-		       "icon-note-2.svg");
-  register_stock_icon (icon_factory, "denemo-eight-note", "icon-note-3.svg");
-  register_stock_icon (icon_factory, "denemo-sixteenth-note",
-		       "icon-note-4.svg");	 
-  register_stock_icon (icon_factory, "denemo-whole-rest", "icon-rest-0.svg");
-  register_stock_icon (icon_factory, "denemo-half-rest", "icon-rest-1.svg");
-  register_stock_icon (icon_factory, "denemo-quarter-rest",
-		       "icon-rest-2.svg");
-  register_stock_icon (icon_factory, "denemo-eight-rest", "icon-rest-3.svg");
-  register_stock_icon (icon_factory, "denemo-sixteenth-rest",
-		       "icon-rest-4.svg");
-
-  //New Ornaments added here, loding XBM's until svgs have been generated.
-  register_stock_icon (icon_factory, "denemo-coda",
-                       "feta26-scripts-coda.xbm");
-  register_stock_icon (icon_factory, "denemo-prall",
-                       "feta26-scripts-prall.xbm");
-  register_stock_icon (icon_factory, "denemo-flageolet",
-                       "feta26-scripts-flageolet.xbm");
-  register_stock_icon (icon_factory, "denemo-prallmordent",
-                       "feta26-scripts-prallmordent.xbm");
-  register_stock_icon (icon_factory, "denemo-prallprall",
-                       "feta26-scripts-prallprall.xbm");
-  register_stock_icon (icon_factory, "denemo-open",
-                       "feta26-scripts-open.xbm");
-  register_stock_icon (icon_factory, "denemo-segno",
-                       "feta26-scripts-segno.xbm");
-  register_stock_icon (icon_factory, "denemo-stopped",
-                       "feta26-scripts-stopped.xbm");
-  register_stock_icon (icon_factory, "denemo-thumb",
-                       "feta26-scripts-thumb.xbm");
-  register_stock_icon (icon_factory, "denemo-upprall",
-                       "feta26-scripts-upprall.xbm");
-  register_stock_icon (icon_factory, "denemo-arpeggio",
-                       "feta26-scripts-arpeggio.xbm");
-
-  //remove accelerators from some gtk standard stock items
-  clean_stock_item(GTK_STOCK_NEW);
-  clean_stock_item(GTK_STOCK_OPEN);
-  clean_stock_item(GTK_STOCK_SAVE);
-  clean_stock_item(GTK_STOCK_CLOSE);
-  clean_stock_item(GTK_STOCK_QUIT);
-  clean_stock_item(GTK_STOCK_CUT);
-  clean_stock_item(GTK_STOCK_COPY);
-  clean_stock_item(GTK_STOCK_PASTE);
-  clean_stock_item(GTK_STOCK_GOTO_FIRST);
-  clean_stock_item(GTK_STOCK_GOTO_LAST);
-  clean_stock_item(GTK_STOCK_ADD);
-  clean_stock_item(GTK_STOCK_REMOVE);
-  clean_stock_item(GTK_STOCK_FIND);
-
-  g_object_unref (icon_factory);
-}
 
 #ifdef HAVE_SIGCHLD
 /* Code by Erik Mouw, taken directly from the gtk+ FAQ */
@@ -639,7 +448,7 @@ main (int argc, char *argv[])
   bind_textdomain_codeset (PACKAGE, "UTF-8");
   textdomain (PACKAGE);
 
-  register_stock_items ();
+  //register_stock_items ();
 
 
   //g_print("Calling scm boot guile with %d and %p\n", argc, argv);
@@ -766,9 +575,9 @@ Report bugs to http://www.denemo.org\n"), NULL) ;
       }
     }
 #endif
-
+#ifdef HAVE_SIGCHLD
   signal (SIGCHLD, sigchld_handler);
-
+#endif
 
     if (optind < argc)
       return argv[optind];
