@@ -731,12 +731,13 @@ showwhichaccidentals (objnode * theobjs, gint initialnum, gint * initialaccs)
 		/* A new accidental not present in the original chord */
 		thetone->showaccidental =
 		  ((chord *) theobj->object)->hasanacc = TRUE;
-	      // FIXME - you should use a script to apply these directives & set hasnacc with that.
-	      else if (thetone->directives && ((DenemoDirective*)thetone->directives->data)->postfix && (* ((DenemoDirective*)thetone->directives->data)    ->postfix->str=='!'|| *  ((DenemoDirective*)thetone->directives->data)    ->postfix->str=='?'))
-	     	thetone->showaccidental =
-	     	  ((chord *) theobj->object)->hasanacc = TRUE;
 	      else
 		thetone->showaccidental = FALSE;
+	      // FIXME - you should use a script to apply these directives & set hasnacc with that.
+	      if(thetone->directives && ((DenemoDirective*)thetone->directives->data)->postfix && ( *((DenemoDirective*)thetone->directives->data)->postfix->str=='!'|| *((DenemoDirective*)thetone->directives->data)->postfix->str=='?'))
+	     	thetone->showaccidental =
+	     	  ((chord *) theobj->object)->hasanacc = (*((DenemoDirective*)thetone->directives->data)->postfix->str=='?')? DENEMO_CAUTIONARY:DENEMO_REMINDER;
+	      
 	    }			/* End second loop through chord */
 	  set_accidental_positions (theobj);
 	  setpixelmin (theobj);
@@ -779,9 +780,4 @@ forceaccidentals (DenemoObject * theobj)
   ((chord *) theobj->object)->hasanacc = TRUE;
   set_accidental_positions (theobj);
   setpixelmin (theobj);
-  if (theobj->user_string)
-    {
-      g_free (theobj->user_string);
-      theobj->user_string = NULL;
-    }
 }
