@@ -120,7 +120,7 @@ static gboolean update_playbutton_callback(gboolean paused) {
 
 void stop_playing() {
   update_position(NULL);
-  g_idle_add_full(G_PRIORITY_HIGH_IDLE, (GSourceFunc)update_playbutton_callback, is_paused(), NULL);
+  g_idle_add_full(G_PRIORITY_HIGH_IDLE, (GSourceFunc)update_playbutton_callback, (gpointer)is_paused(), NULL);
   playing = FALSE;
   play_until = -G_MAXDOUBLE;
   if(Denemo.gui->si && Denemo.gui->si->recorded_midi_track) {
