@@ -15,6 +15,7 @@
 #include "prefops.h"
 #include "utils.h"
 #include "external.h"
+#include "audiointerface.h"
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -28,30 +29,10 @@
 #include <wait.h>
 #endif
 #include <errno.h>
-#include "jackmidi.h"
-#include "fluid.h"
 
 static gint timeout_id = 0, kill_id=0;
 static gdouble duration = 0.0;
 
-gchar *
-get_midi_audio_pointer(gchar *audio_device)
-{
-  if (!strcmp(audio_device, Fluidsynth))
-    return Fluidsynth;
-  else if (!strcmp(audio_device, Jack))
-    return Jack;
-  else if (!strcmp(audio_device, Portaudio))
-    return Portaudio;
-  else if (!strcmp(audio_device, None))
-    return None;
-
-#ifdef _HAVE_FLUIDSYNTH_
-  return Fluidsynth;
-#else 
-  return None;
-#endif
-}
 
 void set_tempo (void) {
   gdouble tempo = Denemo.gui->si->master_tempo;
@@ -73,34 +54,41 @@ void set_tempo (void) {
 void
 ext_midi_playback (GtkAction * action, DenemoScriptParam *param) {
   GET_1PARAM(action, param, callback);
+  
+  set_playbutton(is_paused());
+  if(is_playing()) {
+    toggle_paused();
+    return;
+  }
   set_tempo();
-  if (Denemo.prefs.midi_audio_output == Jack)
-    jack_midi_play(callback);
-  else if (Denemo.prefs.midi_audio_output == Fluidsynth)
-    fluid_midi_play(callback);
-  else infodialog("Nothing chosen to play back on:\nLook in Edit->Change Preferences->MIDI/Audio->MIDI/Audio Output\nRestart Denemo after setting this to Internal Synth.");
+  
+  //rewind_audio(); done in start_audio_playing()
+  start_audio_playing(FALSE);
+  midi_play(callback);
+}
 
+
+// a function that stops any play in progress, and starts play again.
+void restart_play(void) {
+stop_midi_playback(NULL, NULL);
+ext_midi_playback (NULL, NULL);
 }
 
 void stop_midi_playback (GtkAction * action, gpointer param) {
- if (Denemo.prefs.midi_audio_output == Jack){
-   jack_midi_playback_stop();
-   jack_kill_timer();
- }
- else if (Denemo.prefs.midi_audio_output == Fluidsynth){
-   fluid_midi_stop();
- }
-
- gtk_widget_queue_draw (Denemo.scorearea);//update playhead on screen
+  
+  if(is_paused())
+    toggle_paused();
+  else
+    set_playbutton(TRUE);
+  midi_stop();
+  
+  gtk_widget_queue_draw (Denemo.scorearea);//update playhead on screen
 }
 
 void
 playback_panic()
 {
-  if (Denemo.prefs.midi_audio_output == Jack)
-    jack_midi_panic();
-  else if (Denemo.prefs.midi_audio_output == Fluidsynth)
-    fluid_midi_panic();   
+  panic_all();
 }
 
 /** 
@@ -125,7 +113,9 @@ PlaybackRangeDialog(){
 	 GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
 
   hbox = gtk_hbox_new (FALSE, 8);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, TRUE, TRUE, 0);
+  
+  GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+  gtk_container_add (GTK_CONTAINER (content_area), hbox);
 
   //TODO calculate hightest number in seconds
   gdouble max_end_time = 7200.0;
@@ -146,7 +136,7 @@ PlaybackRangeDialog(){
   to_time =
   gtk_spin_button_new_with_range (0.0, max_end_time, 0.1);
   gtk_box_pack_start (GTK_BOX (hbox), to_time, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), to_time, TRUE, TRUE, 0);
+
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (to_time),
 	      (gdouble) gui->si->end_time);
 
@@ -158,9 +148,9 @@ PlaybackRangeDialog(){
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
     {
       gui->si->start_time =
-	gtk_spin_button_get_value_as_float (GTK_SPIN_BUTTON (from_time));
+	gtk_spin_button_get_value (GTK_SPIN_BUTTON (from_time));
       gui->si->end_time =
-	gtk_spin_button_get_value_as_float (GTK_SPIN_BUTTON (to_time));
+	gtk_spin_button_get_value (GTK_SPIN_BUTTON (to_time));
       //gtk_widget_destroy (dialog);
     }
   
