@@ -49,6 +49,8 @@ struct callbackdata
   GtkWidget *pitchspellingprogram;
   GtkWidget *modal;
   GtkWidget *cursor_highlight;
+  GtkWidget *return_key_is_special;
+  GtkWidget *newbie;
   GtkWidget *persistence;
   GtkWidget *startmidiin;
   GtkWidget *applytoselection;
@@ -67,6 +69,8 @@ struct callbackdata
   GtkWidget *visible_directive_buttons;
   GtkWidget *autoupdate;
 
+
+  
   GtkWidget *autosave_timeout;
   GtkWidget *maxhistory;
   GtkWidget *browser;
@@ -108,6 +112,9 @@ struct callbackdata
 
   GtkWidget *display_refresh;
   GtkWidget *animation_steps;
+  GtkWidget *tooltip_timeout;
+  GtkWidget *tooltip_browse_timeout;
+  GtkWidget *tooltip_browse_mode_timeout;
   GtkWidget *profile;
   GtkWidget *midiplayer;
   GtkWidget *audioplayer;
@@ -250,6 +257,9 @@ set_preferences (struct callbackdata *cbdata)
 
   ASSIGNDOUBLE(display_refresh)
   ASSIGNINT(animation_steps)
+  ASSIGNINT(tooltip_timeout)
+  ASSIGNINT(tooltip_browse_timeout)
+  ASSIGNINT(tooltip_browse_mode_timeout)
   ASSIGNTEXT(temperament)
   ASSIGNBOOLEAN(strictshortcuts)
   ASSIGNBOOLEAN(overlays)
@@ -268,11 +278,14 @@ set_preferences (struct callbackdata *cbdata)
   ASSIGNBOOLEAN(modal)
   ASSIGNBOOLEAN(persistence)
   ASSIGNBOOLEAN(cursor_highlight)
+  ASSIGNBOOLEAN(return_key_is_special)
+  ASSIGNBOOLEAN(newbie)
   ASSIGNBOOLEAN(startmidiin)
   ASSIGNBOOLEAN(applytoselection)
   ASSIGNBOOLEAN(quickshortcuts)
   ASSIGNBOOLEAN(autosave)
   ASSIGNINT(autosave_timeout)
+ 
   ASSIGNBOOLEAN(midi_in_controls)
   ASSIGNBOOLEAN(playback_controls)
   ASSIGNBOOLEAN(console_pane)
@@ -316,6 +329,7 @@ midi_audio_tab_update(GtkWidget *box, gpointer data)
   gtk_window_resize(GTK_WINDOW(cbdata->dialog), 1, 1);
 }
 
+//callback for Prefences command
 void
 preferences_change (GtkAction *action, gpointer param)
 {
@@ -326,6 +340,9 @@ preferences_change (GtkAction *action, gpointer param)
   GtkWidget *main_vbox;
   GtkWidget *autosave;
   GtkWidget *autosave_timeout;
+   // GtkWidget *tooltip_timeout;
+   //   GtkWidget *tooltip_browse_timeout;
+    //    GtkWidget *tooltip_browse_mode_timeout;
   GtkWidget *maxhistory;
   GtkWidget *notebook;
   GtkWidget *hbox;
@@ -515,7 +532,9 @@ preferences_change (GtkAction *action, gpointer param)
 
   BOOLEANENTRY("Display Music Snippets", rhythm_palette);
   BOOLEANENTRY("Display menu of objects toolbar", object_palette);
+  //xgettext:no-c-format
   INTENTRY_LIMITS(_("% Zoom"), zoom, 1, 100);
+  //xgettext:no-c-format
   INTENTRY_LIMITS(_("% of display height per system"), system_height, 1, 100);
 
   /*
@@ -538,6 +557,8 @@ preferences_change (GtkAction *action, gpointer param)
 
 
   BOOLEANENTRY("Strict Shortcuts", strictshortcuts);
+  BOOLEANENTRY("Treat Return key as movable shortcut", return_key_is_special);
+  BOOLEANENTRY("Turn on all tooltips", newbie);
 
   /*
    * External (Helper) Programs
@@ -558,12 +579,16 @@ preferences_change (GtkAction *action, gpointer param)
    /*
    * Misc Menu
    */
-  NEWPAGE("Misc");
+  NEWPAGE("Miscellaneous");
   BOOLEANENTRY("Use Denemo modally", modal);
   BOOLEANENTRY("Re-use last settings on startup", persistence);
   DOUBLEENTRY_LIMITS(_("Playback Display Refresh"), display_refresh, 0.001, 0.5, 0.002);
   INTENTRY_LIMITS(_("Page Turn Steps"), animation_steps, 1, 200);
 
+  INTENTRY_LIMITS(_("Tooltip timeout in ms. (0 to use system preference)"), tooltip_timeout, 0, 1000000);
+  INTENTRY_LIMITS(_("Tooltip browse timeout in ms"), tooltip_browse_timeout, 0, 1000000);
+  INTENTRY_LIMITS(_("Tooltip browse mode timeout in ms"), tooltip_browse_mode_timeout, 0, 1000000);
+
   INTENTRY_LIMITS(_("Excerpt Resolution"), resolution, 72, 600);
   BOOLEANENTRY("Enable Thumbnails", enable_thumbnails);
   INTENTRY(_("Max recent files"), maxhistory)
@@ -773,11 +798,15 @@ preferences_change (GtkAction *action, gpointer param)
     {
       set_preferences (&cbdata);
 
+#ifndef G_OS_WIN32
+//under windows we have:  <http://savannah.gnu.org/bugs/?36968>
       // stop playback and restart audio subsystem
       // FIXME: only do this when audio settings actually changed
       midi_stop();
       audio_shutdown();
       audio_initialize(cbdata.prefs);
+#endif
+      
       free_g_lists(&cbdata);
     }
   else
