@@ -102,15 +102,15 @@ initprefs ()
   ret->lilypath = g_string_new ("lilypond.exe");//We don't assume the file assoc works - we are installing this anyway to a known place,the option  neither lilypond-windows.exe nor the -dgui option are used
   ret->pdfviewer = g_string_new ("");
   ret->imageviewer = g_string_new ("");
-
+  ret->profile = g_string_new("Simple");
 #else /* !G_OS_WIN32 */
   ret->browser = g_string_new ("firefox");
   ret->audioplayer = g_string_new ("play");
   ret->lilypath = g_string_new ("lilypond");
   ret->pdfviewer = g_string_new ("evince");
   ret->imageviewer = g_string_new ("eog");
-#endif /* !G_OS_WIN32 */
   ret->profile = g_string_new("Arranger");
+#endif /* !G_OS_WIN32 */
   ret->denemopath = g_string_new (g_get_home_dir());
   ret->lilyversion = g_string_new ("");//meaning use installed LilyPond version
   ret->temperament = g_string_new("Equal");
@@ -121,7 +121,8 @@ initprefs ()
   ret->overlays = FALSE;
   ret->continuous = TRUE;
   ret->cursor_highlight = TRUE;
-
+  ret->return_key_is_special = TRUE;
+  ret->newbie = TRUE;
   ret->immediateplayback = TRUE;
 
   ret->audio_driver = g_string_new("default");
@@ -325,6 +326,9 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       READBOOLXMLENTRY(modal) 
       READBOOLXMLENTRY(persistence) 
       READBOOLXMLENTRY(cursor_highlight) 
+
+      READBOOLXMLENTRY(return_key_is_special) 
+      READBOOLXMLENTRY(newbie) 
       READBOOLXMLENTRY(applytoselection) 
       READBOOLXMLENTRY(quickshortcuts) 
       READBOOLXMLENTRY(startmidiin) 
@@ -334,6 +338,9 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       READINTXMLENTRY(resolution)
       READDOUBLEXMLENTRY(display_refresh)
       READINTXMLENTRY(animation_steps)
+      READINTXMLENTRY(tooltip_timeout)
+      READINTXMLENTRY(tooltip_browse_timeout)
+      READINTXMLENTRY(tooltip_browse_mode_timeout)
       READBOOLXMLENTRY(overlays)
       READBOOLXMLENTRY(enable_thumbnails)
       
@@ -406,6 +413,8 @@ gboolean get_bool_pref(gchar *prefname) {
       GETBOOLPREF(modal) 
       GETBOOLPREF(persistence) 
       GETBOOLPREF(cursor_highlight) 
+      GETBOOLPREF(return_key_is_special) 
+      GETBOOLPREF(newbie) 
       GETBOOLPREF(applytoselection) 
       GETBOOLPREF(quickshortcuts) 
       GETBOOLPREF(startmidiin) 
@@ -443,6 +452,9 @@ gint get_int_pref(gchar *prefname) {
       GETINTPREF(mode) 
       GETINTPREF(resolution)
       GETINTPREF(animation_steps)
+            GETINTPREF(tooltip_timeout)
+	    GETINTPREF(tooltip_browse_timeout)
+	    GETINTPREF(tooltip_browse_timeout)
       GETINTPREF(portaudio_sample_rate)
       GETINTPREF(portaudio_period_size)
       GETINTPREF(zoom)
@@ -755,6 +767,8 @@ writeXMLPrefs (DenemoPrefs * prefs)
   WRITEBOOLXMLENTRY(modal)
   WRITEBOOLXMLENTRY(persistence)
   WRITEBOOLXMLENTRY(cursor_highlight)
+  WRITEBOOLXMLENTRY(return_key_is_special)
+  WRITEBOOLXMLENTRY(newbie)
   WRITEBOOLXMLENTRY(applytoselection)
   WRITEBOOLXMLENTRY(quickshortcuts)
   WRITEBOOLXMLENTRY(startmidiin)
@@ -763,6 +777,9 @@ writeXMLPrefs (DenemoPrefs * prefs)
   WRITEINTXMLENTRY(resolution)
   WRITEDOUBLEXMLENTRY(display_refresh)
   WRITEINTXMLENTRY(animation_steps)
+    WRITEINTXMLENTRY(tooltip_timeout)
+    WRITEINTXMLENTRY(tooltip_browse_timeout)
+    WRITEINTXMLENTRY(tooltip_browse_mode_timeout)
   WRITEBOOLXMLENTRY(overlays)
   WRITEBOOLXMLENTRY(enable_thumbnails)
   WRITEBOOLXMLENTRY(continuous)
