@@ -30,6 +30,18 @@
 #include "utils.h"
 #include "view.h"
 #include "external.h"
+#include "scorelayout.h"
+
+#ifdef G_OS_WIN32
+#define FILE_LOCKING 1
+#else
+#define FILE_LOCKING 0
+#endif
+
+
+#if FILE_LOCKING
+static gchar *printname="denemoprint";
+#endif
 
 #if GTK_MAJOR_VERSION==3
 typedef enum {
@@ -67,6 +79,14 @@ static   GError *lily_err = NULL;
 static
 void print_finished(GPid pid, gint status, GList *filelist);
 
+#if FILE_LOCKING
+static void advance_printname() {
+static counter = 0;
+printname = g_strdup_printf("denemoprint%d", counter++);
+g_print("Printname this time %s\n", printname);
+}
+#endif
+
 /*** 
  * make sure lilypond is in the path defined in the preferences
  */
@@ -210,7 +230,13 @@ check_lily_version (gchar *version)
 static gchar *get_printfile_pathbasename(void) {
   gchar *filename = NULL;
   if(filename==NULL)
-    filename = g_build_filename ( locateprintdir (), "denemoprint", NULL);
+    filename = g_build_filename ( locateprintdir (),
+#if FILE_LOCKING
+    printname,
+#else
+    "denemoprint",
+#endif
+     NULL);
   return filename;
 }       
 /* truncate epoint after 20 lines replacing the last three chars in that case with dots */
@@ -785,6 +811,9 @@ export_pdf (gchar * filename, DenemoGUI * gui)
 
 static void
 print_and_view(gchar **arguments) {
+#if FILE_LOCKING
+advance_printname();
+#endif
   run_lilypond(arguments);
   if(printpid!=GPID_NONE) {
     g_child_watch_add (printpid, (GChildWatchFunc)open_pdfviewer, (gchar *) get_printfile_pathbasename());
@@ -794,8 +823,14 @@ print_and_view(gchar **arguments) {
   }
 }
 
+static gboolean initialize_typesetting(void) {
+  return call_out_to_guile("(InitializeTypesetting)");
+}
 void print_lily_cb (GtkWidget *item, DenemoGUI *gui){
-  if(call_out_to_guile("(InitializeTypesetting)")) {
+#if FILE_LOCKING
+advance_printname();
+#endif
+  if(initialize_typesetting()) {
     g_warning("InitializeTypesetting failed\n");
     return;
   }
@@ -849,9 +884,19 @@ static void normal_cursor(void) {
     gdk_window_set_cursor(gtk_widget_get_window(Denemo.printarea), arrowcursor);
 }
 
-
-
-static void
+/*void                user_function                      (EvPrintOperation       *evprintoperation,
+                                                        GtkPrintOperationResult arg1,
+                                                        gpointer                user_data)             : Run Last */
+void printop_done(EvPrintOperation *printop, GtkPrintOperationResult arg1, GtkPrintSettings **psettings) {
+     if(*psettings)
+      g_object_unref(*psettings);
+    *psettings = ev_print_operation_get_print_settings (printop);
+    g_object_ref(*psettings);
+    //g_print("Came away with uri %s\n", gtk_print_settings_get(*psettings, GTK_PRINT_SETTINGS_OUTPUT_URI));
+    set_current_scoreblock_uri(g_strdup(gtk_print_settings_get(*psettings, GTK_PRINT_SETTINGS_OUTPUT_URI)));
+    call_out_to_guile("(FinalizePrint)");
+}
+static gboolean
 libevince_print(void) {
   GError *err = NULL;
   GFile       *file;
@@ -860,7 +905,7 @@ libevince_print(void) {
 
   if(err) {
     g_warning ("Malformed filename %s\n", filename);
-    return;
+    return -1;
   }
 
   EvDocument *doc = ev_document_factory_get_document (uri, &err);
@@ -869,12 +914,23 @@ libevince_print(void) {
     if(err)
 			g_error_free (err);
     err = NULL;
+    return -1;
   } else {
-    EvPrintOperation *printop = ev_print_operation_new (doc);      
+    static GtkPrintSettings *settings;
+    if(settings==NULL)
+      settings = gtk_print_settings_new();
+    EvPrintOperation *printop = ev_print_operation_new (doc);    
+    g_signal_connect(printop, "done", G_CALLBACK(printop_done), &settings);
+    gtk_print_settings_set(settings, GTK_PRINT_SETTINGS_OUTPUT_URI, get_output_uri_from_scoreblock());
+    ev_print_operation_set_print_settings (printop, settings);
     ev_print_operation_run (printop, NULL);
   }
+  return 0;
 }
 
+gboolean print_typeset_pdf(void){
+return libevince_print();
+}
 static void
 set_printarea_doc(EvDocument *doc) {
   EvDocumentModel  *model;
@@ -1018,7 +1074,8 @@ set_printarea(GError **err) {
     set_printarea_doc(doc);
 
 
-  
+#if 0
+//this will fail if the printarea is not visible, so it would need to be re-triggered on showing the printarea  
     //setting up Denemo.pixbuf so that parts of the pdf can be dragged etc.
   {
       GdkWindow *window = gtk_layout_get_bin_window (GTK_LAYOUT(Denemo.printarea));
@@ -1035,12 +1092,14 @@ set_printarea(GError **err) {
       Denemo.pixbuf = gdk_pixbuf_get_from_window(window, 0,0, width,height);
 #endif
   }
+#endif
   return;
 }
 
 static void
 printview_finished(GPid pid, gint status, gboolean print) {
   progressbar_stop();
+  call_out_to_guile("(FinalizeTypesetting)");
   //g_print("Processing %s\n", (gchar *) get_printfile_pathbasename());
   process_lilypond_errors((gchar *) get_printfile_pathbasename());
   printpid = GPID_NONE;
@@ -1049,11 +1108,17 @@ printview_finished(GPid pid, gint status, gboolean print) {
   if(!err && print)
      libevince_print();
   normal_cursor();
+
+
 }
 
 /* callback to print current part (staff) of score */
 void
 printpart_cb (GtkAction *action, gpointer param) {
+#if FILE_LOCKING
+advance_printname();
+#endif
+
   DenemoGUI *gui = Denemo.gui;
   if(gui->si->markstaffnum)
     if(confirm("A range of music is selected","Print whole file?")){
@@ -1070,8 +1135,11 @@ printpart_cb (GtkAction *action, gpointer param) {
 
 
 static gboolean typeset(gboolean force) {
+#if FILE_LOCKING
+advance_printname();
+#endif
 if((force) || (changecount!=Denemo.gui->changecount)) {
-  if(call_out_to_guile("(InitializeTypesetting)")) {
+  if(initialize_typesetting()) {
       g_warning("InitializeTypesetting failed\n");
       return FALSE;
   }
@@ -1086,8 +1154,11 @@ return FALSE;
 }
 
 static gboolean typeset_movement(gboolean force) {
+#if FILE_LOCKING
+advance_printname();
+#endif
 if((force) || (changecount!=Denemo.gui->changecount)) {
-  if(call_out_to_guile("(InitializeTypesetting)")) {
+  if(initialize_typesetting()) {
       g_warning("InitializeTypesetting failed\n");
       return FALSE;
   }
@@ -1121,6 +1192,9 @@ void refresh_print_view (void) {
 
 static
 void print_from_print_view(gboolean all_movements) {
+#if FILE_LOCKING
+advance_printname();
+#endif
   busy_cursor();
   if(all_movements?typeset(FALSE):typeset_movement(FALSE)) {
     g_child_watch_add(printpid, (GChildWatchFunc)printview_finished, (gpointer)(TRUE));
@@ -1149,7 +1223,8 @@ printexcerptpreview_cb (GtkAction *action, gpointer param) {
     printrangedialog(gui);  //Launch a dialog to get selection
   if(gui->si->selection.firstmeasuremarked){
     gui->lilycontrol.excerpt = TRUE;
-    export_png((gchar *) get_printfile_pathbasename(), (GChildWatchFunc)prepare_preview, gui); 
+    export_png((gchar *) get_printfile_pathbasename(), (GChildWatchFunc)prepare_preview, gui);
+    gui->lilycontrol.excerpt = FALSE;
   }
 }
 
@@ -1331,16 +1406,25 @@ start_drag(GtkWidget *widget, gboolean *flag) {
   return TRUE;
 }
 static void create_all_pdf(void) {
+#if FILE_LOCKING
+advance_printname();
+#endif
 busy_cursor();
 create_pdf(FALSE, TRUE);
 g_child_watch_add(printpid, (GChildWatchFunc)printview_finished, (gpointer)(FALSE));
 }
 static void create_movement_pdf(void) {
+#if FILE_LOCKING
+advance_printname();
+#endif
 busy_cursor();
 create_pdf(FALSE, FALSE);
 g_child_watch_add(printpid, (GChildWatchFunc)printview_finished, (gpointer)(FALSE));
 }
 static void create_part_pdf(void) {
+#if FILE_LOCKING
+advance_printname();
+#endif
 busy_cursor();
 create_pdf(TRUE, TRUE);
 g_child_watch_add(printpid, (GChildWatchFunc)printview_finished, (gpointer)(FALSE));
@@ -1658,8 +1742,9 @@ void show_print_view(GtkAction *action, gpointer param) {
     gtk_window_present(GTK_WINDOW(w));
   else
     gtk_widget_show(w);
-  if(action && changecount!=Denemo.gui->changecount) {
-    typeset_control(NULL, NULL);
+  if(action && (changecount!=Denemo.gui->changecount || Denemo.gui->lilysync != Denemo.gui->changecount) ) {
+    if(!initialize_typesetting())
+      typeset_control(NULL, create_all_pdf);
   }
 }
 
@@ -1700,50 +1785,64 @@ printarea_scroll_event (GtkWidget *widget, GdkEventScroll *event) {
 return FALSE;
 }
 
+static void typeset_action(GtkWidget *button, gpointer data) {
+  initialize_typesetting();
+  typeset_control(NULL, data);
+}
+
 void install_printpreview(DenemoGUI *gui, GtkWidget *top_vbox){ 
   if(Denemo.printarea)
     return;
   busycursor = gdk_cursor_new(GDK_WATCH);
-  arrowcursor = gdk_cursor_new(GDK_RIGHT_PTR);//FIXME what is the system cursor called??
+  arrowcursor = gdk_cursor_new(GDK_RIGHT_PTR);
 
   GtkWidget *main_vbox = gtk_vbox_new (FALSE, 1);
   GtkWidget *main_hbox =  gtk_hbox_new (FALSE, 1);
   gtk_box_pack_start (GTK_BOX (main_vbox), main_hbox,FALSE, TRUE, 0);
   GtkWidget *hbox =  gtk_hbox_new (FALSE, 1);
   gtk_box_pack_start (GTK_BOX (main_hbox), hbox,FALSE, TRUE, 0);
-  GtkWidget *button = gtk_button_new_with_label("Print");
+  GtkWidget *button = gtk_button_new_with_label("Typeset");
+  gtk_widget_set_tooltip_text(button, "Typesets the music using the current score layout. See View->Score Layouts to see which layouts you have created and which is currently selected.");
+  g_signal_connect(button, "clicked", G_CALLBACK(typeset_action), create_all_pdf);
+  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
+
+  button = gtk_button_new_with_label("Print");
+  gtk_widget_set_tooltip_text(button, "Pops up a Print dialog. From this you can send your typeset score to a printer or to a PDF file.");
   g_signal_connect(button, "clicked", G_CALLBACK(libevince_print), NULL);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
 
-
-  button = gtk_button_new_with_label("Refresh");
-  g_signal_connect(button, "clicked", G_CALLBACK(typeset_control), NULL);
-  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
-  
-  button = gtk_button_new_with_label("Score");
-  g_signal_connect(button, "clicked", G_CALLBACK(typeset_control), create_all_pdf);
-  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
+    
 
   button = gtk_button_new_with_label("Movement");
-  g_signal_connect(button, "clicked", G_CALLBACK(typeset_control), create_movement_pdf);
+  gtk_widget_set_tooltip_text(button, _("Typesets the music from the current movement. This creates a score layout comprising one movement."));
+  g_signal_connect(button, "clicked", G_CALLBACK(typeset_action), create_movement_pdf);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
  
   button = gtk_button_new_with_label("Part");
-  g_signal_connect(button, "clicked", G_CALLBACK(typeset_control), create_part_pdf);
+  gtk_widget_set_tooltip_text(button, _("Typesets the music from the current part for all movements. A part is all the music with the same staff-name. This creates a score layout with one part, all movements."));
+  g_signal_connect(button, "clicked", G_CALLBACK(typeset_action), create_part_pdf);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
 
+  button = gtk_button_new_with_label("Refresh");
+  gtk_widget_set_tooltip_text(button, _("Re-issues the last print command. Use this after modifying the file to repeat the typesetting."));
+  g_signal_connect(button, "clicked", G_CALLBACK(typeset_action), NULL);
+  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
+ 
   hbox =  gtk_hbox_new (FALSE, 1);
   gtk_box_pack_end (GTK_BOX (main_hbox), hbox,FALSE, TRUE, 0);
 
 
   button = gtk_button_new_with_label("Duplex");
+  gtk_widget_set_tooltip_text(button, _("Shows pages side by side, so you can see page turns for back-to-back printing\n"));
   g_signal_connect(button, "clicked", G_CALLBACK(dual_page), NULL);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
 
   button = gtk_button_new_with_label("Next");
+  gtk_widget_set_tooltip_text(button, _("Move to the next page - you can also scroll with the scroll-wheel, and zoom with control-wheel"));
   g_signal_connect(button, "clicked", G_CALLBACK(page_display), (gpointer) 1);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
   button = gtk_button_new_with_label("Previous");
+  gtk_widget_set_tooltip_text(button, _("Move to the previous page - you can also scroll with the scroll-wheel, and zoom with control-wheel"));
   g_signal_connect(button, "clicked", G_CALLBACK(page_display), (gpointer) -1);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
 
@@ -1768,8 +1867,10 @@ void install_printpreview(DenemoGUI *gui, GtkWidget *top_vbox){
   ev_init();
   
   Denemo.printarea = (GtkWidget*)ev_view_new();
-  gtk_container_add (GTK_CONTAINER(score_and_scroll_hbox), Denemo.printarea);
 
+  gtk_container_add (GTK_CONTAINER(score_and_scroll_hbox), Denemo.printarea);
+  if(Denemo.prefs.newbie)
+    gtk_widget_set_tooltip_markup(score_and_scroll_hbox, _("This window shows the final typeset score from which you can print or (via print to file) create a PDF document.\nWhen you have typeset the score you can click on a note to move to that place in the Denemo display.\n<b>Note</b>: It can take some time to generate a beautifully typeset score, so take a break!\nIf you just want to generate a score layout - e.g. for one part then you can kill off the actual typsetting by closing the Progress bar"));
 
  g_signal_connect (G_OBJECT (Denemo.printarea), "external-link",
 		      G_CALLBACK (goto_position), NULL);
