@@ -66,6 +66,8 @@ append_movement(GtkAction *action, gpointer param,  gboolean populate) {
   DenemoGUI *gui = Denemo.gui;
   DenemoScore *source_movement = gui->si;
   GList *g;
+  (void)signal_structural_change(gui);
+    
   if(gui->si->lyricsbox)
     gtk_widget_hide(gui->si->lyricsbox);
   point_to_empty_movement(gui);
@@ -130,8 +132,7 @@ void
 delete_movement(GtkAction *action, gpointer param) {
   DenemoGUI *gui = Denemo.gui;
   terminate_playback();
-  if(!confirm_deletestaff_custom_scoreblock(gui))
-    return;
+  (void)signal_structural_change(gui);
   GString *primary = g_string_new(""), *secondary = g_string_new("");
   if(gui->movements==NULL || (g_list_length(gui->movements)==1)) {
     g_string_assign(primary, _("This is the only movement"));
@@ -440,6 +441,7 @@ init_score (DenemoScore * si, DenemoGUI *gui)
   si->undo_guard = 1;//do not collect undo information until file is loaded
   
   si->buttonbox = gtk_hbox_new(FALSE, 1);
+  gtk_widget_set_tooltip_text(si->buttonbox, _("A button bar that can be populated by Movement titles and other user generated buttons.\nGenerally by clicking the button you can edit the title or value or execute the action of the button"));
   gtk_box_pack_end (GTK_BOX (gui->buttonboxes), si->buttonbox, FALSE, TRUE,
 		      0);
   gtk_widget_show (si->buttonbox);
@@ -472,6 +474,7 @@ GList *extract_verses(GList *verses){
   return ret;
 }
 /**
+ * FIXME there is a muddle here between DenemoScore and DenemoGUI
  * frees the data in the passed scoreinfo stucture 
  *
  * @param si pointer to the scoreinfo structure to free
@@ -559,6 +562,7 @@ DenemoScore * clone_movement(DenemoScore *si) {
 	//	widget_for_staff_directive(directive);
       }
     }
+    thestaff->voice_directives = clone_directives(srcStaff->voice_directives);
     {GList *direc;
       for(direc=thestaff->voice_directives;direc;direc=direc->next) {
 	DenemoDirective *directive = direc->data;
