@@ -201,22 +201,7 @@ insert_staff (DenemoScore * si, DenemoStaff * thestaffstruct,
 
 }
 
-//CREATE a GtkMenus to popup when clicking to left of the staff
-GtkMenu * create_menu(GList *directives) {
-    //hmm, cannot populate it, why not ? FIXME 
-    GtkWidget *item;
-    //thestaffstruct->staffmenu = 
-      return (GtkMenu *)gtk_menu_new();
-    //item = gtk_menu_item_new_with_label("Edit Attributes");
-    //gtk_menu_shell_append(GTK_MENU_SHELL( thestaffstruct->staffmenu), item);
-    //g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(edit_staff_directive), NULL);
-    //gtk_widget_show(item);
-    //thestaffstruct->voicemenu = (GtkMenu *)gtk_menu_new();
-    //item = gtk_menu_item_new_with_label("Edit Attributes");
-    //gtk_menu_shell_append(GTK_MENU_SHELL( thestaffstruct->voicemenu), item);
-    //g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(edit_voice_directive), NULL);
-    //gtk_widget_show(item);
-}
+
 
 /**
  * Create and insert a new staff into the score
@@ -240,8 +225,8 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action,
 
 
  
-  thestaffstruct->staffmenu = create_menu(NULL);
-  thestaffstruct->voicemenu = create_menu(NULL);
+  thestaffstruct->staffmenu = (GtkMenu *)gtk_menu_new();
+  thestaffstruct->voicemenu = (GtkMenu *)gtk_menu_new();
 
 
   struct newstaffinfotopass itp;
@@ -332,10 +317,8 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action,
   if (action == NEWVOICE)
     g_string_sprintf (thestaffstruct->denemo_name, _("poly voice %d"),
 		      numstaffs + 1);
-  else if (action == LYRICSTAFF)
-    g_string_sprintf (thestaffstruct->denemo_name, _("lyrics"));
-  else if (action == FIGURESTAFF)
-    g_string_sprintf (thestaffstruct->denemo_name, _("figures"));
+  else if (action == INITIAL)
+    g_string_sprintf (thestaffstruct->denemo_name, _("unnamed"));
   else
     g_string_sprintf (thestaffstruct->denemo_name, _("voice %d"),
 		      numstaffs + 1);
@@ -421,17 +404,11 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action,
 }
 
 
-gboolean confirm_insertstaff_custom_scoreblock(DenemoGUI *gui) {
-  if(gui->custom_scoreblocks)
-    return confirm("Custom LilyPond Score Block", "You will need to edit the LilyPond text to make this change show in the print-out. Proceed?");
+gboolean signal_structural_change(DenemoGUI *gui) {
+  gui->layout_sync = gui->changecount;
   return TRUE;
 }
 
-gboolean confirm_deletestaff_custom_scoreblock(DenemoGUI *gui) {
-  if(gui->custom_scoreblocks)
-    return confirm("Custom LilyPond Score Block", "You will need to edit the LilyPond text to delete any reference to the deleted staff(s) in the scoreblock. Proceed?");
-  return TRUE;
-}
 
 
 /**
@@ -448,8 +425,7 @@ deletestaff (DenemoGUI * gui, gboolean interactive)
   DenemoScore *si = gui->si;
   DenemoStaff *curstaffstruct = si->currentstaff->data;
  
-  if(interactive && !confirm_deletestaff_custom_scoreblock(gui))
-    return;
+  (void)signal_structural_change(gui);
   if(si->currentstaff==NULL)
     return;
   
@@ -627,8 +603,8 @@ void
 newstaffbefore (GtkAction *action, gpointer param)
 {
   DenemoGUI *gui = Denemo.gui;
-  if(!confirm_insertstaff_custom_scoreblock(gui))
-    return;
+  (void)signal_structural_change(gui);
+   
   movetostart(NULL, NULL);
   newstaff (gui, BEFORE, DENEMO_NONE);
   if(gui->si->currentstaffnum>= gui->si->top_staff)
@@ -653,7 +629,7 @@ void
 dnm_newstaffafter (GtkAction *action, gpointer param)
 {
   DenemoGUI *gui = Denemo.gui;
-  if(!confirm_insertstaff_custom_scoreblock(gui))
+  if(!signal_structural_change(gui))
     return;
   movetostart(NULL, NULL);
   newstaff (gui, AFTER, DENEMO_NONE);
