@@ -205,7 +205,7 @@ progressbar (gchar *msg)
     else
       pdata->window = gtk_window_new (GTK_WINDOW_POPUP);
     gtk_window_set_title (GTK_WINDOW (pdata->window), _("Progress")); 
- 
+    gtk_widget_set_tooltip_text(pdata->window, _("This indicates the the LilyPond typsetter is still working on setting the Denemo score. This can take a long time, particularly for polyphony where voices must not collide. You can continue editing while the typsetting is taking place.\nKill this window if you want to re-start the typesetting e.g. after fixing a mistake you just spotted."));
     vbox = gtk_vbox_new (FALSE, 5);
     gtk_container_add (GTK_CONTAINER (pdata->window), vbox);
     gtk_widget_show (vbox);
@@ -1087,6 +1087,9 @@ define_scheme_literal_variable("Denemo-Note8", NOTE8, NULL);
 define_scheme_literal_variable("Denemo-Rest8", REST8, NULL);
 
 }
+
+#define HIGHLIGHT "<span background=\"lightblue\"> "
+
 /* markup the passed string to be in the denemo music font
 * caller must free the returned string
 */
@@ -1098,79 +1101,79 @@ gchar * music_font(gchar *str) {
 
       case '0':  g_string_append(s, " "NOTE0" ");
 	break;
-      case HIGHLIGHT_OFFSET+'0': g_string_append(s, "<span background=\"blue\"> "NOTE0" </span>");
+      case HIGHLIGHT_OFFSET+'0': g_string_append(s, HIGHLIGHT NOTE0" </span>");
 	break;
 
       case '1':  g_string_append(s, " "NOTE1" ");
 	break;
-      case HIGHLIGHT_OFFSET+'1': g_string_append(s, "<span background=\"blue\"> "NOTE1" </span>");
+      case HIGHLIGHT_OFFSET+'1': g_string_append(s, HIGHLIGHT NOTE1" </span>");
 	break;
       case '2':  g_string_append(s, " "NOTE2" ");
 	break;
-      case HIGHLIGHT_OFFSET+'2': g_string_append(s, "<span background=\"blue\"> "NOTE2" </span>");
+      case HIGHLIGHT_OFFSET+'2': g_string_append(s, HIGHLIGHT NOTE2" </span>");
 	break;
       case '3':  g_string_append(s, " "NOTE3" ");
 	break;
-      case HIGHLIGHT_OFFSET+'3': g_string_append(s, "<span background=\"blue\"> "NOTE3" </span>");
+      case HIGHLIGHT_OFFSET+'3': g_string_append(s, HIGHLIGHT NOTE3" </span>");
 	break;
       case '4':  g_string_append(s, " "NOTE4" ");
 	break;
-      case HIGHLIGHT_OFFSET+'4': g_string_append(s, "<span background=\"blue\"> "NOTE4" </span>");
+      case HIGHLIGHT_OFFSET+'4': g_string_append(s, HIGHLIGHT NOTE4" </span>");
 	break;
       case '5':  g_string_append(s, " "NOTE5" ");
 	break;
-      case HIGHLIGHT_OFFSET+'5': g_string_append(s, "<span background=\"blue\"> "NOTE5" </span>");
+      case HIGHLIGHT_OFFSET+'5': g_string_append(s, HIGHLIGHT NOTE5" </span>");
 	break;
       case '6':  g_string_append(s, " "NOTE6" ");
 	break;
-      case HIGHLIGHT_OFFSET+'6': g_string_append(s, "<span background=\"blue\"> "NOTE6" </span>");
+      case HIGHLIGHT_OFFSET+'6': g_string_append(s, HIGHLIGHT NOTE6" </span>");
 	break;
       case '7':  g_string_append(s, " "NOTE7" ");
 	break;
-      case HIGHLIGHT_OFFSET+'7': g_string_append(s, "<span background=\"blue\"> "NOTE7" </span>");
+      case HIGHLIGHT_OFFSET+'7': g_string_append(s, HIGHLIGHT NOTE7" </span>");
 	break;
       case '8':  g_string_append(s, " "NOTE8" ");
 	break;
-      case HIGHLIGHT_OFFSET+'8': g_string_append(s, "<span background=\"blue\"> "NOTE8" </span>");
+      case HIGHLIGHT_OFFSET+'8': g_string_append(s, HIGHLIGHT NOTE8" </span>");
 	break;
 
 
      case 'r':  g_string_append(s, " "REST0" ");
 	break;
-     case HIGHLIGHT_OFFSET+'r': g_string_append(s, "<span background=\"blue\"> "REST0" </span>");
+     case HIGHLIGHT_OFFSET+'r': g_string_append(s, HIGHLIGHT REST0" </span>");
 	break;
 
      case 's':  g_string_append(s, " "REST1" ");
 	break;
-     case HIGHLIGHT_OFFSET+'s': g_string_append(s, "<span background=\"blue\"> "REST1" </span>");
+     case HIGHLIGHT_OFFSET+'s': g_string_append(s, HIGHLIGHT REST1" </span>");
 	break;
      case 't':  g_string_append(s, " "REST2" ");
 	break;
-     case HIGHLIGHT_OFFSET+'t': g_string_append(s, "<span background=\"blue\"> "REST2" </span>");
+     case HIGHLIGHT_OFFSET+'t': g_string_append(s, HIGHLIGHT REST2" </span>");
 	break;
      case 'u':  g_string_append(s, " "REST3" ");
 	break;
-     case HIGHLIGHT_OFFSET+'u': g_string_append(s, "<span background=\"blue\"> "REST3" </span>");
+     case HIGHLIGHT_OFFSET+'u': g_string_append(s, HIGHLIGHT REST3" </span>");
 	break;
      case 'v':  g_string_append(s, " "REST4" ");
 	break;
-     case HIGHLIGHT_OFFSET+'v': g_string_append(s, "<span background=\"blue\"> "REST4" </span>");
+     case HIGHLIGHT_OFFSET+'v': g_string_append(s, HIGHLIGHT REST4" </span>");
 	break;
      case 'w':  g_string_append(s, " "REST5" ");
 	break;
-     case HIGHLIGHT_OFFSET+'w': g_string_append(s, "<span background=\"blue\"> "REST5" </span>");
+     case HIGHLIGHT_OFFSET+'w': g_string_append(s, HIGHLIGHT REST5" </span>");
 	break;
      case 'x':  g_string_append(s, " "REST6" ");
 	break;
-     case HIGHLIGHT_OFFSET+'x': g_string_append(s, "<span background=\"blue\"> "REST6" </span>");
+     case HIGHLIGHT_OFFSET+'x': g_string_append(s, HIGHLIGHT REST6" </span>");
 	break;
      case 'y':  g_string_append(s, " "REST7" ");
 	break;
-     case HIGHLIGHT_OFFSET+'y': g_string_append(s, "<span background=\"blue\"> "REST7" </span>");
+     case HIGHLIGHT_OFFSET+'y': g_string_append(s, HIGHLIGHT REST7" </span>");
 	break;
      case 'z':  g_string_append(s, " "REST8" ");
 	break;
-     case HIGHLIGHT_OFFSET+'z': g_string_append(s, "<span background=\"blue\"> "REST8" </span>");
+     case HIGHLIGHT_OFFSET+'z': g_string_append(s, HIGHLIGHT REST8" </span>");
 	break;
 
 
@@ -1211,11 +1214,11 @@ void  set_title_bar(DenemoGUI *gui) {
 }
 static const gchar* enshift_string(gint enshift) {
 switch(enshift) {
-    case -2: return "bb";
-    case -1: return "b";
+    case -2: return "𝄫";
+    case -1: return "♭";
     case 0: return " ";
-    case 1: return "#";
-    case 2: return "##";
+    case 1: return "♯";
+    case 2: return "𝄪";
     default: return "Error";
 }
 }
@@ -1313,51 +1316,23 @@ void write_status(DenemoGUI *gui) {
     case KEYSIG:
       selection = g_strdup_printf("key signature change");
       break;
-    case BARLINE:
-      selection = g_strdup_printf("special barline type %d", 	((barline *) curObj->object)->type);// FIXME names for these
-      break;
     case STEMDIRECTIVE:
       selection = g_strdup_printf("stem directive: %s",((stemdirective *) curObj->object)->type==DENEMO_STEMDOWN?
 				  "stem down":((stemdirective *) curObj->object)->type==DENEMO_STEMUP?"stem up":
 				  "normal stemming");
       break;
-    case MEASUREBREAK:
-      selection = g_strdup_printf("measurebreak");
-      break;
-    case STAFFBREAK:
-      selection = g_strdup_printf("staffbreak");
-      break;
     case DYNAMIC:
       selection = g_strdup_printf("Dynamic: %s", ((dynamic *) curObj->object)->type->str  );
       break;
-    case GRACE_START:
-      selection = g_strdup_printf("Start Grace Notes: %s duration %d ", ((grace *) curObj->object)->on_beat?"On beat":"Before beat",
-				  ((grace *) curObj->object)->duration);
-      break;
-    case GRACE_END:
-      selection = g_strdup_printf("Grace note end");
-      break;
-    case LYRIC:
-      selection = g_strdup_printf("Lyric: %s",  ((lyric *) curObj->object)->lyrics->str  );
-      break;
-    case FIGURE:
-      selection = g_strdup_printf("Figure");
-      break;
 
     case LILYDIRECTIVE:
       {
-	DenemoDirective *directive = (DenemoDirective *)curObj->object;
-	
-      selection = g_strdup_printf("Lily directive: %.50s", directive->postfix?directive->postfix->str:directive->prefix?directive->prefix->str:directive->graphic_name?directive->graphic_name->str:directive->display?directive->display->str:"empty");
+      DenemoDirective *directive = (DenemoDirective *)curObj->object;
+      selection = g_strdup_printf("Directive:(%.20s) %.20s%.50s", directive->tag?directive->tag->str:"Unknown Tag",
+            directive->x?"Not all layouts":directive->y?"Only for one Layout":"",
+            directive->postfix?directive->postfix->str:directive->prefix?directive->prefix->str:directive->graphic_name?directive->graphic_name->str:directive->display?directive->display->str:"empty");
       }
       break;
-
-    case FAKECHORD:
-      selection = g_strdup_printf("Fakechord"   );
-      break;
-    case PARTIAL:
-      selection = g_strdup_printf("Partial"   );
-      break;
     default:
       selection = g_strdup_printf("Cursor on a unknown object");
     }
@@ -1441,11 +1416,15 @@ gchar *
 string_dialog_entry (DenemoGUI *gui, gchar *title, gchar *instruction, gchar *initial_value)
 {
   return string_dialog_entry_with_widget (gui, title, instruction, initial_value, NULL);
+}
+static void get_entry(GtkWidget *dialog, gint response, GtkWidget *entry) {
+
+
 }
 
 /* as string_dialog_entry() but with extra widget */
 gchar *
-string_dialog_entry_with_widget (DenemoGUI *gui, gchar *wlabel, gchar *direction, gchar *PreValue, GtkWidget *widget)
+string_dialog_entry_with_widget_opt (DenemoGUI *gui, gchar *wlabel, gchar *direction, gchar *PreValue, GtkWidget *widget, gboolean modal)
 {
 
  	GtkWidget *dialog;
@@ -1455,12 +1434,16 @@ string_dialog_entry_with_widget (DenemoGUI *gui, gchar *wlabel, gchar *direction
 	GString *string;
 	entry = gtk_entry_new ();
 
-	dialog = gtk_dialog_new_with_buttons (wlabel,
+	dialog = modal? gtk_dialog_new_with_buttons (wlabel,
                                         GTK_WINDOW (Denemo.window),
-                                        (GtkDialogFlags) (GTK_DIALOG_MODAL |
-                                                       GTK_DIALOG_DESTROY_WITH_PARENT),
+                                        (GtkDialogFlags) (GTK_DIALOG_DESTROY_WITH_PARENT),
                                         GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+                                        NULL):
+                                        gtk_dialog_new_with_buttons (wlabel,
+                                        GTK_WINDOW (Denemo.window),
+                                        (GtkDialogFlags) (GTK_DIALOG_DESTROY_WITH_PARENT),
+                                        GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
                                         NULL);
 
 	label = gtk_label_new (direction);
@@ -1476,13 +1459,15 @@ string_dialog_entry_with_widget (DenemoGUI *gui, gchar *wlabel, gchar *direction
 	gtk_container_add(GTK_CONTAINER(content_area), entry);
 
 	gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
-      	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
-        gtk_widget_grab_focus (entry);
-  	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+  //gtk_widget_grab_focus (entry);
+  //gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
 	gtk_window_set_keep_above(GTK_WINDOW (dialog), TRUE);
-        gtk_widget_show_all (dialog);
-
+  gtk_widget_show_all (dialog);
+  
+  if(modal) {
+    gtk_widget_grab_focus (entry);
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT){ 
 		entry_string = (gchar *) gtk_entry_get_text (GTK_ENTRY (entry));
 		string = g_string_new(entry_string);
@@ -1494,6 +1479,92 @@ string_dialog_entry_with_widget (DenemoGUI *gui, gchar *wlabel, gchar *direction
 		return NULL;
 	}
   return NULL;
+  } else {
+    g_signal_connect_swapped (dialog,"response", G_CALLBACK (gtk_main_quit), entry);
+    gtk_main();
+    entry_string = (gchar *) gtk_entry_get_text (GTK_ENTRY (entry));
+		string = g_string_new(entry_string);
+    gtk_widget_destroy (dialog);
+		return g_string_free(string, FALSE);
+  }
+}
+
+gchar *
+string_dialog_entry_with_widget (DenemoGUI *gui, gchar *wlabel, gchar *direction, gchar *PreValue, GtkWidget *widget) {
+  return string_dialog_entry_with_widget_opt (gui, wlabel, direction, PreValue, widget, TRUE); 
+}
+
+/* as string_dialog_entry_with_widget() but gives a text editor instead of a single line editor */
+gchar *
+string_dialog_editor_with_widget_opt (DenemoGUI *gui, gchar *wlabel, gchar *direction, gchar *PreValue, GtkWidget *widget, gboolean modal)
+{
+ 	GtkWidget *dialog;
+	GtkWidget *textview;
+	GtkWidget *label;
+	textview = gtk_text_view_new ();
+  GtkTextBuffer *textbuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));
+  gtk_text_buffer_set_text(textbuffer, PreValue?PreValue:"", -1);
+  GtkWidget *sw = gtk_scrolled_window_new (NULL, NULL);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+  
+	dialog = modal? gtk_dialog_new_with_buttons (wlabel,
+                                        GTK_WINDOW (Denemo.window),
+                                        (GtkDialogFlags) ( GTK_DIALOG_DESTROY_WITH_PARENT),
+                                        GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+                                        GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+                                        NULL):
+                  gtk_dialog_new_with_buttons (wlabel,
+                                        GTK_WINDOW (Denemo.window),
+                                        (GtkDialogFlags) ( GTK_DIALOG_DESTROY_WITH_PARENT),
+                                        GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+                                        NULL);
+
+	label = gtk_label_new (direction);
+	GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+  gtk_box_pack_start(GTK_BOX(content_area), label, FALSE, TRUE, 0);
+	if(widget) {
+    gtk_box_pack_start(GTK_BOX(content_area), widget, FALSE, TRUE, 0);
+    g_object_set_data(G_OBJECT(widget), "textbuffer", textbuffer);
+     g_object_set_data(G_OBJECT(widget), "textview", textview);
+  }
+  gtk_container_add(GTK_CONTAINER(sw), textview);
+  gtk_box_pack_start(GTK_BOX(content_area), sw, TRUE, TRUE, 0);
+
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+  
+  
+	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
+	gtk_window_set_keep_above(GTK_WINDOW (dialog), TRUE);
+  gtk_widget_show_all (dialog);
+  if(modal) {
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT){
+      GtkTextIter startiter, enditer;
+      gtk_text_buffer_get_start_iter (textbuffer, &startiter);
+      gtk_text_buffer_get_end_iter (textbuffer, &enditer);
+      gchar *text = gtk_text_buffer_get_text (textbuffer, &startiter, &enditer, FALSE);
+      gtk_widget_destroy (dialog);
+      return  text;
+	}
+	else {  
+		gtk_widget_destroy (dialog);
+		return NULL;
+	}
+  return NULL;
+  } else {
+    g_signal_connect_swapped (dialog,"response", G_CALLBACK (gtk_main_quit), NULL);
+    gtk_main();
+    GtkTextIter startiter, enditer;
+    gtk_text_buffer_get_start_iter (textbuffer, &startiter);
+    gtk_text_buffer_get_end_iter (textbuffer, &enditer);
+    gchar *text = gtk_text_buffer_get_text (textbuffer, &startiter, &enditer, FALSE);
+    gtk_widget_destroy (dialog);
+		return text;
+  }
+}
+
+gchar *
+string_dialog_editor_with_widget (DenemoGUI *gui, gchar *wlabel, gchar *direction, gchar *PreValue, GtkWidget *widget) {
+  return string_dialog_editor_with_widget_opt (gui, wlabel, direction, PreValue, widget, TRUE); 
 }
 
 static gboolean
@@ -1515,7 +1586,7 @@ gchar * get_option(gchar *str, gint length) {
 						   GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 						   GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
 						   NULL);
-  gtk_dialog_set_default_response(dialog, GTK_RESPONSE_ACCEPT);
+  gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);
   GtkWidget *vbox = gtk_vbox_new(FALSE, 1);
   GtkWidget *content_area = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
   gtk_container_add(GTK_CONTAINER(content_area), vbox);
@@ -1629,3 +1700,22 @@ void switch_back_to_main_window(void) {
   gtk_window_present(GTK_WINDOW(Denemo.window));
   gtk_widget_grab_focus (Denemo.scorearea);
 }
+
+/* set all labels in the hierarchy below widget to use markup */
+void use_markup(GtkWidget *widget)
+{
+  if (!widget)
+	return;
+  if(GTK_IS_LABEL(widget)) {
+    gtk_label_set_use_markup (GTK_LABEL (widget), TRUE);
+  }
+  else
+ if(GTK_IS_CONTAINER(widget)) {
+    GList *g = gtk_container_get_children (GTK_CONTAINER(widget));
+    for(;g;g=g->next)
+      use_markup(g->data);
+    if (GTK_IS_MENU_ITEM(widget)) {
+      use_markup(gtk_menu_item_get_submenu(GTK_MENU_ITEM(widget)));
+    }
+ }
+}
